@@ -107,8 +107,7 @@ sub lock_and_get_rw_config()
 # and sets up the corresponding environment variables.
 sub get_crossover_config()
 {
-    # Set to the default values so they can be used in [EnvironmentVariables]
-    $ENV{CX_BOTTLE_PATH} ||= get_user_bottle_dir() || "";
+    # Set to the default value so it can be used in [EnvironmentVariables]
     $ENV{CX_MANAGED_BOTTLE_PATH} ||= get_managed_bottle_dir();
 
     require CXConfig;
@@ -122,6 +121,12 @@ sub get_crossover_config()
         $cxconfig->read("$user_dir/$cellarid.conf");
         set_environment($cxconfig, "User environment variables");
     }
+
+    if (!$ENV{CX_BOTTLE_PATH})
+    {
+        my $config_bottle_path=$cxconfig->get("CrossOver", "BottlePath", "");
+        $ENV{CX_BOTTLE_PATH} = $config_bottle_path || get_user_bottle_dir() || "";
+    }
     return $cxconfig;
 }
 
