@@ -69,8 +69,7 @@ def delete_bottle(bottle, window):
 
         bottle.delete(delete_bottle_callback)
 
-        config = cxproduct.get_config()
-        ask_for_ratings = config['CrossOver'].get('AskForRatings', '1') != '0'
+        ask_for_ratings = cxproduct.get_config_boolean('CrossOver', 'AskForRatings', True)
         if bottle.appid and ask_for_ratings:
             ratingdialog.RatingController(bottle, window, True, False)
 
@@ -98,33 +97,6 @@ def quit_bottle(bottle, force, callback=None):
         bottle.quit(callback)
 
 
-def set_esync_state(bottle, state, window):
-    if state != (bottle.is_esync_enabled_state == bottle.STATUS_ESYNC_ENABLED):
-        if state:
-            primary_text = _("Some Windows applications will not work correctly with ESync enabled.")
-            buttons = ((Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL),
-                       (_("Reboot Bottle and Enable ESync"), Gtk.ResponseType.OK))
-        else:
-            primary_text = None
-            buttons = ((Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL),
-                       (_("Reboot Bottle and Disable ESync"), Gtk.ResponseType.OK))
-
-        secondary_text = _("Changing this setting will reboot the bottle and cause any running applications in the bottle to quit. Are you sure you want to do this?")
-
-        def toggle_esync_response(response):
-            if response == Gtk.ResponseType.OK:
-                if state:
-                    bottle.enable_esync()
-                else:
-                    bottle.disable_esync()
-            else:
-                bottle.bottle_changed()
-
-        cxguitools.CXMessageDlg(primary=primary_text, secondary=secondary_text, button_array=buttons,
-                                response_function=toggle_esync_response,
-                                message_type=Gtk.MessageType.WARNING, parent=window)
-
-
 def set_highres_state(bottle, state, window):
     if state == bottle.is_high_resolution_enabled():
         return
