@@ -25,7 +25,6 @@ class BottleQuery(cxobjc.Proxy):
 class NotFoundError(Exception):
     pass
 
-registrationBottlePrefix = "registrationTestBottle"
 
 def _validate_wineprefix(prefix):
     if prefix == "":
@@ -54,7 +53,6 @@ reserved_names = ['default', 'icons', 'installers', 'logs', 'tie']
 
 _bottleListCache = []
 
-@cxobjc.method(BottleQuery, 'bottles')
 def get_bottle_list():
     # pylint: disable=W0603
     global _bottleListCache
@@ -72,8 +70,6 @@ def get_bottle_list():
 
                 if bottlecandidate.lower() in reserved_names:
                     continue
-                if bottlecandidate.lower().startswith(registrationBottlePrefix.lower()):
-                    continue
                 if not _validate_wineprefix(os.path.join(dirpath, bottlecandidate)):
                     continue
 
@@ -129,9 +125,7 @@ def is_valid_new_bottle_name(new_bottle_name):
     return True
 
 
-@cxobjc.method(BottleQuery, 'defaultBottle')
 def get_default_bottle():
-
     for path in [cxproduct.get_bottle_path(), cxproduct.get_managed_bottle_path()]:
         for dirpath in path.split(":"):
             if not os.path.exists(dirpath):
@@ -143,7 +137,6 @@ def get_default_bottle():
     return ""
 
 
-@cxobjc.method(BottleQuery, 'prefixForBottle_')
 def get_prefix_for_bottle(bottlename):
     for path in [cxproduct.get_bottle_path(), cxproduct.get_managed_bottle_path()]:
         for dirpath in path.split(":"):
@@ -287,28 +280,32 @@ def get_control_panel_info(bottlename, windowsdir=None):
                 # appwiz.cpl is installed because we need it as a back-end.
                 #  It's pretty much meaningless in this context, though.
                 continue
+            if distversion.IS_MACOSX and applet_id.lower() == "desk.cpl/0":
+                # The Display Settings control panel is broken on macOS.
+                continue
             section = cplDB[applet_id]
             path = section.get('Path', '')
             if path != '':
-                if applet_id.lower() == "joy.cpl/0":
-                    icon_path = "joy"
-                elif applet_id.lower() == "inetcpl.cpl/0":
-                    icon_path = "inetcpl"
-                else:
-                    icon_path = resolve_icon_path(section.get('Icon', ''),
-                                                  bottlename)
                 AppletTable.append([path, section.get('Name', ''),
-                                    section.get('Description', ''),
-                                    icon_path])
+                                    section.get('Description', '')])
 
     # Special case:  Add winecfg
-    AppletTable.append(["winecfg.exe", _("Wine Configuration"), _("Built-in tool for configuring bottle settings"), "winecfg"])
+    AppletTable.append(["winecfg.exe", _("Wine Configuration"),
+                        _("Built-in tool for configuring bottle settings")])
 
     # Task Manager...
-    AppletTable.append(["taskmgr.exe", _("Task Manager"), _("Manage the applications and processes running in this bottle"), "winetaskmgr"])
+    AppletTable.append(["taskmgr.exe", _("Task Manager"),
+                        _("Manage the applications and processes running in this bottle")])
 
     # And reboot.
-    AppletTable.append(["reboot.exe", _("Simulate Reboot"), _("Simulate a system reboot in this bottle"), "cxreboot"])
+    AppletTable.append(["wineboot.exe", _("Simulate Reboot"),
+                        _("Simulate a system reboot in this bottle")])
+
+    if not distversion.IS_MACOSX:
+        AppletTable.append(["cxassoceditui", _("Edit Associations"),
+                            _("Manage the Windows programs used to open files in the native environment")])
+        AppletTable.append(["cxmenueditui", _("Edit Menus"),
+                            _("Manage the menus and desktop icons in this bottle")])
 
     return AppletTable
 
@@ -360,7 +357,7 @@ def resolve_icon_path(iconPath, bottlename):
         return nativePath
     return ""
 
-@cxobjc.method(BottleQuery, 'shutdownManipulatorForBottle_')
+
 def shutdown_manipulator(bottlename):
     try:
         manipulator = BottleManipulator(bottlename)
@@ -767,35 +764,36 @@ def unset_registry_value(bottlename, path, name, arch=REG_NATIVE):
 
 WindowsVersion = collections.namedtuple(
     'WindowsVersion',
-    ['Version', 'Description', 'CurrentVersion', 'MajorVersion', 'MinorVersion', 'BuildNumber',
+    ['Version', 'Description', 'CurrentVersion', 'MajorVersion', 'MinorVersion', 'BuildNumber', 'UBR',
      'PlatformId', 'CSDVersion', 'ServicePackMajor', 'ServicePackMinor', 'ProductType'])
 
 # from winecfg/appdefaults.c and ntdll/version.c
 _windows_versions = [
-    WindowsVersion("win11", "Windows 11", "6.3", 10, 0, 22000, 2, " ", 0, 0, "WinNT"),
-    WindowsVersion("win10", "Windows 10", "6.3", 10, 0, 19043, 2, " ", 0, 0, "WinNT"),
-    WindowsVersion("win81", "Windows 8.1", None, 6, 3, 9600, 2, " ", 0, 0, "WinNT"),
-    WindowsVersion("win8", "Windows 8", None, 6, 2, 9200, 2, " ", 0, 0, "WinNT"),
-    WindowsVersion("win2008r2", "Windows 2008 R2", None, 6, 1, 7601, 2, "Service Pack 1", 1, 0, "ServerNT"),
-    WindowsVersion("win7", "Windows 7", None, 6, 1, 7601, 2, "Service Pack 1", 1, 0, "WinNT"),
-    WindowsVersion("win2008", "Windows 2008", None, 6, 0, 6002, 2, "Service Pack 1", 0, 0, "ServerNT"),
-    WindowsVersion("vista", "Windows Vista", None, 6, 0, 6002, 2, "Service Pack 2", 2, 0, "WinNT"),
-    WindowsVersion("win2003", "Windows 2003", None, 5, 2, 3790, 2, "Service Pack 2", 2, 0, "ServerNT"),
-    WindowsVersion("winxp", "Windows XP", None, 5, 1, 2600, 2, "Service Pack 3", 3, 0, "WinNT"),
-    WindowsVersion("win2k", "Windows 2000", None, 5, 0, 2195, 2, "Service Pack 4", 4, 0, "WinNT"),
-    WindowsVersion("winme", "Windows ME", None, 4, 90, 3000, 1, " ", 0, 0, ""),
-    WindowsVersion("win98", "Windows 98", None, 4, 10, 2222, 1, " A ", 0, 0, ""),
-    WindowsVersion("win95", "Windows 95", None, 4, 0, 950, 1, "", 0, 0, ""),
-    WindowsVersion("nt40", "Windows NT 4.0", None, 4, 0, 1381, 2, "Service Pack 6a", 6, 0, "WinNT"),
-    WindowsVersion("nt351", "Windows NT 3.5", None, 3, 51, 1057, 2, "Service Pack 2", 0, 0, "WinNT"),
-    WindowsVersion("win31", "Windows 3.1", None, 3, 10, 0, 0, "Win32s 1.3", 0, 0, ""),
-    WindowsVersion("win30", "Windows 3.0", None, 3, 0, 0, 0, "Win32s 1.3", 0, 0, ""),
-    WindowsVersion("win20", "Windows 2.0", None, 2, 0, 0, 0, "Win32s 1.3", 0, 0, ""),
+    WindowsVersion("win11", "Windows 11", "6.3", 10, 0, 22000, 588, 2, " ", 0, 0, "WinNT"),
+    WindowsVersion("win10", "Windows 10", "6.3", 10, 0, 19045, 5796, 2, " ", 0, 0, "WinNT"),
+    WindowsVersion("win81", "Windows 8.1", None, 6, 3, 9600, 0, 2, " ", 0, 0, "WinNT"),
+    WindowsVersion("win8", "Windows 8", None, 6, 2, 9200, 0, 2, " ", 0, 0, "WinNT"),
+    WindowsVersion("win2008r2", "Windows 2008 R2", None, 6, 1, 7601, 0, 2, "Service Pack 1", 1, 0, "ServerNT"),
+    WindowsVersion("win7", "Windows 7", None, 6, 1, 7601, 0, 2, "Service Pack 1", 1, 0, "WinNT"),
+    WindowsVersion("win2008", "Windows 2008", None, 6, 0, 6002, 0, 2, "Service Pack 1", 0, 0, "ServerNT"),
+    WindowsVersion("vista", "Windows Vista", None, 6, 0, 6002, 0, 2, "Service Pack 2", 2, 0, "WinNT"),
+    WindowsVersion("win2003", "Windows 2003", None, 5, 2, 3790, 0, 2, "Service Pack 2", 2, 0, "ServerNT"),
+    WindowsVersion("winxp", "Windows XP", None, 5, 1, 2600, 0, 2, "Service Pack 3", 3, 0, "WinNT"),
+    WindowsVersion("win2k", "Windows 2000", None, 5, 0, 2195, 0, 2, "Service Pack 4", 4, 0, "WinNT"),
+    WindowsVersion("winme", "Windows ME", None, 4, 90, 3000, 0, 1, " ", 0, 0, ""),
+    WindowsVersion("win98", "Windows 98", None, 4, 10, 2222, 0, 1, " A ", 0, 0, ""),
+    WindowsVersion("win95", "Windows 95", None, 4, 0, 950, 0, 1, "", 0, 0, ""),
+    WindowsVersion("nt40", "Windows NT 4.0", None, 4, 0, 1381, 0, 2, "Service Pack 6a", 6, 0, "WinNT"),
+    WindowsVersion("nt351", "Windows NT 3.5", None, 3, 51, 1057, 0, 2, "Service Pack 2", 0, 0, "WinNT"),
+    WindowsVersion("win31", "Windows 3.1", None, 3, 10, 0, 0, 0, "Win32s 1.3", 0, 0, ""),
+    WindowsVersion("win30", "Windows 3.0", None, 3, 0, 0, 0, 0, "Win32s 1.3", 0, 0, ""),
+    WindowsVersion("win20", "Windows 2.0", None, 2, 0, 0, 0, 0, "Win32s 1.3", 0, 0, ""),
 ]
 
 _gettable_versions = [
-    WindowsVersion("win10", "Windows 10", "6.3", 10, 0, 18362, 2, " ", 0, 0, "WinNT"),
-    WindowsVersion("win10", "Windows 10", None, 10, 0, 10240, 2, " ", 0, 0, "WinNT"),
+    WindowsVersion("win10", "Windows 10", "6.3", 10, 0, 19043, 1466, 2, " ", 0, 0, "WinNT"),
+    WindowsVersion("win10", "Windows 10", "6.3", 10, 0, 18362, 0, 2, " ", 0, 0, "WinNT"),
+    WindowsVersion("win10", "Windows 10", None, 10, 0, 10240, 0, 2, " ", 0, 0, "WinNT"),
 ]
 _gettable_versions.extend(_windows_versions)
 
@@ -809,8 +807,8 @@ version_nicknames = {
     "win2k8r2": "win2008r2",
 }
 _settable_versions = [
-    WindowsVersion("winxpsp1", "Windows XP", None, 5, 1, 2600, 2, "Service Pack 1", 1, 0, "WinNT"),
-    WindowsVersion("winxpsp2", "Windows XP", None, 5, 1, 2600, 2, "Service Pack 2", 2, 0, "WinNT"),
+    WindowsVersion("winxpsp1", "Windows XP", None, 5, 1, 2600, 0, 2, "Service Pack 1", 1, 0, "WinNT"),
+    WindowsVersion("winxpsp2", "Windows XP", None, 5, 1, 2600, 0, 2, "Service Pack 2", 2, 0, "WinNT"),
 ]
 _settable_versions.extend(_windows_versions)
 
@@ -824,7 +822,7 @@ def set_windows_version(bottlename, version):
     config = get_config(bottlename)
     if version == 'winxp' and config["Bottle"].get("WineArch", 'win32') == 'win64':
         # 64-bit winxp version info is different
-        info = WindowsVersion("winxp", "Windows XP", None, 5, 2, 3790, 2, "Service Pack 3", 3, 0, "WinNT")
+        info = WindowsVersion("winxp", "Windows XP", None, 5, 2, 3790, 0, 2, "Service Pack 3", 3, 0, "WinNT")
 
     if info.PlatformId == 0: # VER_PLATFORM_WIN32s
         unset_registry_value(bottlename, 'HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows NT\\CurrentVersion',
@@ -839,6 +837,10 @@ def set_windows_version(bottlename, version):
                              'CurrentBuildNumber', REG_BOTH)
         unset_registry_value(bottlename, 'HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows NT\\CurrentVersion',
                              'CurrentBuild', REG_BOTH)
+        unset_registry_value(bottlename, 'HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows NT\\CurrentVersion',
+                             'ProductName', REG_BOTH)
+        unset_registry_value(bottlename, 'HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows NT\\CurrentVersion',
+                             'UBR', REG_BOTH)
         unset_registry_value(bottlename, 'HKEY_LOCAL_MACHINE\\System\\CurrentControlSet\\Control\\ProductOptions',
                              'ProductType', REG_BOTH)
         unset_registry_value(bottlename, 'HKEY_LOCAL_MACHINE\\System\\CurrentControlSet\\Control\\Windows',
@@ -865,6 +867,10 @@ def set_windows_version(bottlename, version):
                              'CurrentBuildNumber', REG_BOTH)
         unset_registry_value(bottlename, 'HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows NT\\CurrentVersion',
                              'CurrentBuild', REG_BOTH)
+        unset_registry_value(bottlename, 'HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows NT\\CurrentVersion',
+                             'ProductName', REG_BOTH)
+        unset_registry_value(bottlename, 'HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows NT\\CurrentVersion',
+                             'UBR', REG_BOTH)
         unset_registry_value(bottlename, 'HKEY_LOCAL_MACHINE\\System\\CurrentControlSet\\Control\\ProductOptions',
                              'ProductType', REG_BOTH)
         unset_registry_value(bottlename, 'HKEY_LOCAL_MACHINE\\System\\CurrentControlSet\\Control\\Windows',
@@ -891,6 +897,14 @@ def set_windows_version(bottlename, version):
                          'CurrentBuildNumber', 'str:%d' % info.BuildNumber, REG_BOTH)
         set_registry_key(bottlename, 'HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows NT\\CurrentVersion',
                          'CurrentBuild', 'str:%d' % info.BuildNumber, REG_BOTH)
+        set_registry_key(bottlename, 'HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows NT\\CurrentVersion',
+                         'ProductName', 'str:Microsoft ' + info.Description, REG_BOTH)
+        if info.UBR:
+            set_registry_key(bottlename, 'HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows NT\\CurrentVersion',
+                             'UBR', 'dword:%02x' % info.UBR, REG_BOTH)
+        else:
+            unset_registry_value(bottlename, 'HKEY_LOCAL_MACHINE\\Software\\Microsoft\\Windows NT\\CurrentVersion',
+                                 'UBR', REG_BOTH)
         set_registry_key(bottlename, 'HKEY_LOCAL_MACHINE\\System\\CurrentControlSet\\Control\\ProductOptions',
                          'ProductType', 'str:' + info.ProductType, REG_BOTH)
         set_registry_key(bottlename, 'HKEY_LOCAL_MACHINE\\System\\CurrentControlSet\\Control\\Windows',
@@ -953,7 +967,6 @@ def get_windows_version(bottlename):
     return best_guess.Version
 
 
-@cxobjc.method(BottleQuery, 'displayNameForVersion_')
 def get_windows_version_name(version):
     version = version_nicknames.get(version, version)
 
@@ -963,22 +976,6 @@ def get_windows_version_name(version):
 
     return _('Unknown')
 
-@cxobjc.method(BottleQuery, 'setNativeBrowserForBottle_')
-def set_native_browser(bottlename):
-    """Register winebrowser as the default web browser in the given bottle, so
-    links are opened in the system native browser."""
-    assocs = ('htmlfile', 'xmlfile', 'ftp', 'http', 'https')
-    for assoc in assocs:
-        set_registry_key(bottlename, 'HKEY_CLASSES_ROOT\\%s\\shell\\open\\command' % assoc,
-                         '', '\"c:\\windows\\system32\\winebrowser.exe\" -nohome')
-        set_registry_key(bottlename, 'HKEY_CLASSES_ROOT\\%s\\shell\\open\\ddeexec' % assoc,
-                         '', '"%1",,-1,0,,,,')
-        set_registry_key(bottlename, 'HKEY_CLASSES_ROOT\\%s\\shell\\open\\ddeexec' % assoc,
-                         'NoActivateHandler', '')
-        set_registry_key(bottlename, 'HKEY_CLASSES_ROOT\\%s\\shell\\open\\ddeexec\\Application' % assoc,
-                         '', 'IExplore')
-        set_registry_key(bottlename, 'HKEY_CLASSES_ROOT\\%s\\shell\\open\\ddeexec\\Topic' % assoc,
-                         '', 'WWW_OpenURL')
 
 def get_unix_environ(bottlename=None):
     """Get the Unix environment that should be in effect for the specified
