@@ -53,10 +53,6 @@ class BottleViewController(iconview.IconViewController):
         self.xml.get_object('Description').get_buffer().connect('changed', self.on_Description_changed)
         self.xml.get_object('Description').get_buffer().connect('insert-text', self.on_Description_insert_text)
 
-        self.force_quit = False
-        self.updating_sidebar = False
-        self.updating_description = False
-
         self.control_panel_ready = False
         self.control_panel_spinner = None
         self.control_panel_widget = None
@@ -67,22 +63,21 @@ class BottleViewController(iconview.IconViewController):
     def on_expander_activate(self, _widget):
         expander_states = []
         expander_states.append(self.xml.get_object('BottleActions').get_expanded())
-        expander_states.append(self.xml.get_object('AdvancedOptions').get_expanded())
+        expander_states.append(self.xml.get_object('AdvancedSettings').get_expanded())
         expander_states.append(self.xml.get_object('ControlPanels').get_expanded())
         expander_states.append(self.xml.get_object('BottleDetails').get_expanded())
 
-        cxproduct.set_config_value('OfficeSetup', 'ExpanderStates',
-                                   '\0'.join(str(int(i)) for i in expander_states).encode('unicode_escape'))
+        cxproduct.set_config_string('OfficeSetup', 'ExpanderStates',
+                                    '\0'.join(str(int(i)) for i in expander_states).encode('unicode_escape'))
 
     def load_expander_states(self):
-        config = cxproduct.get_config()
-        expander_states = config['OfficeSetup'].get('ExpanderStates')
+        expander_states = cxproduct.get_config_string('OfficeSetup', 'ExpanderStates', '')
         if not expander_states:
             return
 
         expander_states = [bool(int(i)) for i in cxutils.string_to_utf8(expander_states).decode('unicode_escape').split('\0')]
         self.xml.get_object('BottleActions').set_expanded(expander_states[0])
-        self.xml.get_object('AdvancedOptions').set_expanded(expander_states[1])
+        self.xml.get_object('AdvancedSettings').set_expanded(expander_states[1])
         self.xml.get_object('ControlPanels').set_expanded(expander_states[2])
         self.xml.get_object('BottleDetails').set_expanded(expander_states[3])
 
@@ -220,8 +215,6 @@ class BottleViewController(iconview.IconViewController):
         self.xml.get_object('InstallMissingIcon').hide()
 
     def update_sidebar(self):
-        self.updating_sidebar = True
-
         self.xml.get_object('RunCommandButton').set_tooltip_text(
             _("Select a command to run in the '%s' bottle") % self.bottle.name)
 
@@ -253,14 +246,6 @@ class BottleViewController(iconview.IconViewController):
         backend = application.lookup_action('graphics').get_state().get_string()
         self.xml.get_object('GraphicsComboBox').set_active_id(backend)
 
-        self.xml.get_object('ESyncButtonBox').set_tooltip_text(_("Performance enhanced synchronization"))
-        if self.bottle.is_esync_enabled_state == self.bottle.STATUS_ESYNC_UNKNOWN:
-            self.xml.get_object('ESyncButtonBox').set_sensitive(False)
-        elif self.bottle.is_esync_enabled_state == self.bottle.STATUS_ESYNC_ENABLED:
-            self.xml.get_object('ESyncButtonBox').set_sensitive(True)
-        elif self.bottle.is_esync_enabled_state == self.bottle.STATUS_ESYNC_DISABLED:
-            self.xml.get_object('ESyncButtonBox').set_sensitive(True)
-
         self.xml.get_object('HighResButtonBox').set_tooltip_text(_("High resolution mode"))
         if self.bottle.is_high_resolution_enabled_state == self.bottle.STATUS_HIGHRES_UNKNOWN:
             self.xml.get_object('HighResButtonBox').set_sensitive(False)
@@ -286,8 +271,9 @@ class BottleViewController(iconview.IconViewController):
 
         if self.bottle.is_managed or self.bottle.is_disabled:
             self.xml.get_object('GraphicsButtonBox').set_sensitive(False)
-            self.xml.get_object('ESyncButtonBox').set_sensitive(False)
             self.xml.get_object('HighResButtonBox').set_sensitive(False)
+        else:
+            self.xml.get_object('GraphicsButtonBox').set_sensitive(True)
 
         if self.bottle.is_managed:
             self.xml.get_object('PreviewButtonBox').set_sensitive(False)
@@ -299,8 +285,6 @@ class BottleViewController(iconview.IconViewController):
 
         self.update_description()
 
-        self.updating_sidebar = False
-
     def on_control_panel_clicked(self, _widget, control_panel):
         self.bottle.launch_control_panel_applet(control_panel['exe'])
 
@@ -316,7 +300,7 @@ class BottleViewController(iconview.IconViewController):
                         'joy.cpl',
                         'cxassoceditui',
                         'cxmenueditui',
-                        'reboot.exe',
+                        'wineboot.exe',
                         'taskmgr.exe',
                         'inetcpl.cpl']
 
@@ -470,9 +454,7 @@ class BottleViewController(iconview.IconViewController):
 
         new_description = text_buffer.get_text(text_buffer.get_start_iter(), text_buffer.get_end_iter(), True)
         self.bottle.current_description = new_description
-        if not self.updating_description:
-            self.updating_description = True
-            pyop.sharedOperationQueue.enqueue(UpdateDescriptionOperation(self.bottle, self))
+        self.bottle.write_description()
 
     @staticmethod
     def on_Description_insert_text(text_buffer, _iter, text, _length):
@@ -500,39 +482,11 @@ class BottleViewController(iconview.IconViewController):
 
         bottleoperation.quit_bottle(self.bottle, self.bottle.can_force_quit)
 
-    # Operation delegate functions
-    def op_finished(self, operation):
-        if isinstance(operation, UpdateDescriptionOperation):
-            self.updating_description = False
-
     # BottleWrapper delegate functions
     def bottleChanged(self, _bottle):
-        GLib.idle_add(self.update_launchers)
-        GLib.idle_add(self.update_sidebar)
-        GLib.idle_add(self.update_status)
-        GLib.idle_add(self.update_header)
+        assert pyop.is_main_thread()
 
-
-class UpdateDescriptionOperation(pyop.PythonOperation):
-    def __init__(self, bottle, delegate):
-        pyop.PythonOperation.__init__(self)
-        self.bottle = bottle
-        self.bottle_name = bottle.name
-        self.delegate = delegate
-        self.succeeded = False
-
-    def __unicode__(self):
-        return "UpdateDescriptionOperation for " + self.bottle_name
-
-    def enqueued(self):
-        pyop.PythonOperation.enqueued(self)
-        self.succeeded = False
-
-    def main(self):
-        self.bottle.write_description()
-        self.succeeded = True
-
-    def finish(self):
-        pyop.PythonOperation.finish(self)
-        if self.succeeded:
-            self.delegate.op_finished(self)
+        self.update_launchers()
+        self.update_sidebar()
+        self.update_status()
+        self.update_header()
