@@ -49,9 +49,14 @@ class BottleWrapper(cxobjc.Proxy):
     STATUS_GRAPHICS_BACKEND_DXVK = "Graphics: DXVK"
     STATUS_GRAPHICS_BACKEND_WINE = "Graphics: Wine"
 
-    STATUS_ESYNC_UNKNOWN = "ESync: Unknown"
-    STATUS_ESYNC_ENABLED = "ESync: Enabled"
-    STATUS_ESYNC_DISABLED = "ESync: Disabled"
+    STATUS_VULKAN_BACKEND_UNKNOWN = "Vulkan: Unknown"
+    STATUS_VULKAN_BACKEND_MOLTENVK = "Vulkan: MoltenVK"
+    STATUS_VULKAN_BACKEND_MTLVK = "Vulkan: MTLVK"
+
+    STATUS_DLSS_UNKNOWN = "DLSS: Unknown"
+    STATUS_DLSS_ENABLED = "DLSS: Enabled"
+    STATUS_DLSS_DISABLED = "DLSS: Disabled"
+    STATUS_DLSS_UNAVAILABLE = "DLSS: Unavailable"
 
     STATUS_HIGHRES_UNKNOWN = "High resolution mode: Unknown"
     STATUS_HIGHRES_ENABLED = "High resolution mode: Enabled"
@@ -85,6 +90,9 @@ class BottleWrapper(cxobjc.Proxy):
     isD3DMetalAvailable = cxobjc.object_property(python_name="is_d3dmetal_available", typestr=cxobjc.BOOL)
     isDXMTAvailable = cxobjc.object_property(python_name="is_dxmt_available", typestr=cxobjc.BOOL)
 
+    isMoltenVKAvailable = cxobjc.object_property(python_name="is_moltenvk_available", typestr=cxobjc.BOOL)
+    isMTLVKAvailable = cxobjc.object_property(python_name="is_mtlvk_available", typestr=cxobjc.BOOL)
+
     controlPanelTable = cxobjc.array_property(python_name="control_panel_table")
     isControlPanelReady = cxobjc.object_property(
         python_name="control_panel_ready", typestr=cxobjc.BOOL)
@@ -124,14 +132,17 @@ class BottleWrapper(cxobjc.Proxy):
         self.is_d3dmetal_available = False
         self.is_dxmt_available = False
 
-        self.is_esync_enabled_state = BottleWrapper.STATUS_ESYNC_UNKNOWN
+        self.vulkan_backend_state = BottleWrapper.STATUS_VULKAN_BACKEND_UNKNOWN
+        self.is_moltenvk_available = False
+        self.is_mtlvk_available = False
+
+        self.is_dlss_enabled_state = BottleWrapper.STATUS_DLSS_UNKNOWN
 
         self.is_high_resolution_enabled_ready = False
         self.is_high_resolution_enabled_loading = False
         self.is_high_resolution_enabled_state = BottleWrapper.STATUS_HIGHRES_UNKNOWN
 
         self.is_msync_enabled_state = BottleWrapper.STATUS_MSYNC_UNKNOWN
-
         self.is_preview_enabled_state = BottleWrapper.STATUS_PREVIEW_UNKNOWN
 
         self.installed_packages = {}
@@ -214,6 +225,16 @@ class BottleWrapper(cxobjc.Proxy):
         wconfig[section][name] = value
         wconfig.save_and_unlock_file()
 
+    def unset_config_value(self, section, name):
+        wconfig = self.config.get_save_config()
+        if not wconfig:
+            cxlog.warn("Unable to unset a config value in bottle %s" % cxlog.to_str(self.name))
+            return
+
+        wconfig.lock_file()
+        del wconfig[section][name]
+        wconfig.save_and_unlock_file()
+
     def suspend(self):
         self.add_status_override(BottleWrapper.STATUS_SUSPENDED)
 
@@ -239,7 +260,7 @@ class BottleWrapper(cxobjc.Proxy):
         self.load_basic_info()
 
         self.system_drive = os.path.join(self.wine_prefix, 'drive_c')
-        self.is_default = (self.name == bottlequery.get_default_bottle())
+        self.is_default = self.name == bottlequery.get_default_bottle()
         self.menu = cxmenu.MenuPrefs(self.name, self.is_managed)
 
         self.add_windows_version_observer()
@@ -269,7 +290,7 @@ class BottleWrapper(cxobjc.Proxy):
         self.refresh_up_to_date()
 
         self.load_graphics_backend_info()
-        self.load_is_esync_enabled()
+        self.load_vulkan_backend_info()
         self.load_is_msync_enabled()
         self.load_is_preview_enabled()
 
@@ -365,14 +386,16 @@ class BottleWrapper(cxobjc.Proxy):
     #
     #####
 
+    @staticmethod
     @cxobjc.python_method
-    def is_macos14(self):
+    def is_macos_version(version):
         mac_ver = platform.mac_ver()[0]
         mac_ver = mac_ver.split('.')[0]
-        return distversion.IS_MACOSX and mac_ver and int(mac_ver) >= 14
+        return distversion.IS_MACOSX and mac_ver and int(mac_ver) >= version
 
+    @staticmethod
     @cxobjc.python_method
-    def is_apple_silicon(self):
+    def is_apple_silicon():
         is_apple_silicon = False
         if 'arm' in platform.machine():
             is_apple_silicon = True
@@ -383,14 +406,14 @@ class BottleWrapper(cxobjc.Proxy):
             libc = ctypes.CDLL(ctypes.util.find_library("c"))
             ret = ctypes.c_int()
             if libc.sysctlbyname(b"sysctl.proc_translated", ctypes.byref(ret), ctypes.byref(ctypes.c_size_t(4)), None, ctypes.c_size_t(0)) == 0:
-                if (ret.value == 1):
+                if ret.value == 1:
                     is_apple_silicon = True
 
         return is_apple_silicon
 
     @cxobjc.python_method
     def load_graphics_backend_info(self):
-        if self.is_macos14() and self.is_apple_silicon():
+        if self.is_macos_version(14) and self.is_apple_silicon():
             self.is_d3dmetal_available = True
             self.is_dxmt_available = True
 
@@ -406,6 +429,8 @@ class BottleWrapper(cxobjc.Proxy):
         else:
             self.graphics_backend_state = BottleWrapper.STATUS_GRAPHICS_BACKEND_AUTO
 
+        self.load_is_dlss_enabled()
+
     @cxobjc.namedSelector(b'setGraphicsBackendAuto')
     def set_graphics_backend_auto(self):
         self.set_config_value("EnvironmentVariables", "CX_GRAPHICS_BACKEND", "")
@@ -465,67 +490,133 @@ class BottleWrapper(cxobjc.Proxy):
         return self.graphics_backend_state == BottleWrapper.STATUS_GRAPHICS_BACKEND_WINE
 
     isWineD3DEnabled = cxobjc.object_property(read_only=True, typestr=cxobjc.BOOL,
-                                           getter=is_wined3d_enabled,
-                                           depends_on=["graphics_backend_state"])
+                                              getter=is_wined3d_enabled,
+                                              depends_on=["graphics_backend_state"])
 
     #####
     #
-    # load esync preferences
+    # Vulkan backends
     #
     #####
 
     @cxobjc.python_method
-    def load_is_esync_enabled(self):
-        self.is_esync_enabled_state = BottleWrapper.STATUS_ESYNC_UNKNOWN
+    def load_vulkan_backend_info(self):
+        self.vulkan_backend_state = BottleWrapper.STATUS_VULKAN_BACKEND_UNKNOWN
 
-        enabled = self.get_config_value("EnvironmentVariables", "WINEESYNC", "0") != "0"
-        if enabled:
-            self.is_esync_enabled_state = BottleWrapper.STATUS_ESYNC_ENABLED
+        if distversion.IS_MACOSX:
+            self.is_moltenvk_available = True
+        if self.is_macos_version(15) and self.is_apple_silicon():
+            self.is_mtlvk_available = True
+
+        backend = self.get_config_value("EnvironmentVariables", "CX_LIBVULKAN", "")
+        if self.is_mtlvk_available and backend == "libvulkan.dylib":
+            self.vulkan_backend_state = BottleWrapper.STATUS_VULKAN_BACKEND_MTLVK
+        elif self.is_moltenvk_available:
+            self.vulkan_backend_state = BottleWrapper.STATUS_VULKAN_BACKEND_MOLTENVK
+
+    @cxobjc.namedSelector(b'setVulkanBackendMoltenVK')
+    def set_vulkan_backend_moltenvk(self):
+        self.set_config_value("EnvironmentVariables", "CX_LIBVULKAN", "libMoltenVK.dylib")
+        self.load_vulkan_backend_info()
+        self.bottle_changed()
+
+    @cxobjc.namedSelector(b'setVulkanBackendMTLVK')
+    def set_vulkan_backend_mtlvk(self):
+        self.set_config_value("EnvironmentVariables", "CX_LIBVULKAN", "libvulkan.dylib")
+        self.load_vulkan_backend_info()
+        self.bottle_changed()
+
+    @cxobjc.python_method
+    def is_moltenvk_enabled(self):
+        return self.vulkan_backend_state == BottleWrapper.STATUS_VULKAN_BACKEND_MOLTENVK
+
+    isMoltenVKEnabled = cxobjc.object_property(read_only=True, typestr=cxobjc.BOOL,
+                                               getter=is_moltenvk_enabled,
+                                               depends_on=["vulkan_backend_state"])
+
+    @cxobjc.python_method
+    def is_mtlvk_enabled(self):
+        return self.vulkan_backend_state == BottleWrapper.STATUS_VULKAN_BACKEND_MTLVK
+
+    isMTLVKEnabled = cxobjc.object_property(read_only=True, typestr=cxobjc.BOOL,
+                                            getter=is_mtlvk_enabled,
+                                            depends_on=["vulkan_backend_state"])
+
+    #####
+    #
+    # load dlss preferences
+    #
+    #####
+
+    @cxobjc.python_method
+    def load_is_dlss_enabled(self):
+        self.is_dlss_enabled_state = BottleWrapper.STATUS_DLSS_UNKNOWN
+
+        if not self.graphics_backend_state in (BottleWrapper.STATUS_GRAPHICS_BACKEND_AUTO,
+                                               BottleWrapper.STATUS_GRAPHICS_BACKEND_D3DMETAL,
+                                               BottleWrapper.STATUS_GRAPHICS_BACKEND_DXMT):
+            self.is_dlss_enabled_state = BottleWrapper.STATUS_DLSS_UNAVAILABLE
+            return
+
+        if not self.is_macos_version(14) or not self.is_apple_silicon():
+            self.is_dlss_enabled_state = BottleWrapper.STATUS_DLSS_UNAVAILABLE
+            return
+
+        if self.is_d3dmetal_enabled() and not self.is_macos_version(16):
+            self.is_dlss_enabled_state = BottleWrapper.STATUS_DLSS_UNAVAILABLE
+            return
+
+        d3dmetal_enabled = self.get_config_value("EnvironmentVariables", "D3DM_ENABLE_METALFX", "0") != "0"
+        dxmt_enabled = self.get_config_value("EnvironmentVariables", "DXMT_ENABLE_NVEXT", "0") != "0"
+
+        # Enable DLSS for DXMT if it was enabled for D3DMetal before
+        # it was available for DXMT.
+        if d3dmetal_enabled and not dxmt_enabled:
+            self.set_config_value("EnvironmentVariables", "DXMT_ENABLE_NVEXT", "1")
+            dxmt_enabled = True
+
+        # Enable DLSS for D3DMetal if it was enabled for DXMT, and the
+        # OS has been updated to Tahoe since then.
+        if dxmt_enabled and not d3dmetal_enabled and self.is_macos_version(16):
+            self.set_config_value("EnvironmentVariables", "D3DM_ENABLE_METALFX", "1")
+
+        if dxmt_enabled:
+            self.is_dlss_enabled_state = BottleWrapper.STATUS_DLSS_ENABLED
         else:
-            self.is_esync_enabled_state = BottleWrapper.STATUS_ESYNC_DISABLED
+            self.is_dlss_enabled_state = BottleWrapper.STATUS_DLSS_DISABLED
 
-    @cxobjc.python_method
-    def _enable_esync(self):
-        if self.is_msync_enabled():
-            self._disable_msync()
-
-        self.set_config_value("EnvironmentVariables", "WINEESYNC", "1")
-        self.is_esync_enabled_state = BottleWrapper.STATUS_ESYNC_ENABLED
+    @cxobjc.namedSelector(b'enableDLSS')
+    def enable_dlss(self):
+        self.set_config_value("EnvironmentVariables", "D3DM_ENABLE_METALFX",
+                              "1" if self.is_macos_version(16) else "0")
+        self.set_config_value("EnvironmentVariables", "DXMT_ENABLE_NVEXT", "1")
+        self.is_dlss_enabled_state = BottleWrapper.STATUS_DLSS_ENABLED
 
         self.bottle_changed()
 
-    @cxobjc.namedSelector(b'enableESync')
-    def enable_esync(self):
-        def quit_callback():
-            self._enable_esync()
-            self.resume()
-
-        self.suspend()
-        self.quit(quit_callback)
-
-    @cxobjc.python_method
-    def _disable_esync(self):
-        self.set_config_value("EnvironmentVariables", "WINEESYNC", "0")
-        self.is_esync_enabled_state = BottleWrapper.STATUS_ESYNC_DISABLED
+    @cxobjc.namedSelector(b'disableDLSS')
+    def disable_dlss(self):
+        self.set_config_value("EnvironmentVariables", "D3DM_ENABLE_METALFX", "0")
+        self.set_config_value("EnvironmentVariables", "DXMT_ENABLE_NVEXT", "0")
+        self.is_dlss_enabled_state = BottleWrapper.STATUS_DLSS_DISABLED
 
         self.bottle_changed()
 
-    @cxobjc.namedSelector(b'disableESync')
-    def disable_esync(self):
-        def quit_callback():
-            self._disable_esync()
-            self.resume()
+    @cxobjc.python_method
+    def is_dlss_enabled(self):
+        return self.is_dlss_enabled_state == BottleWrapper.STATUS_DLSS_ENABLED
 
-        self.suspend()
-        self.quit(quit_callback)
+    isDLSSEnabled = cxobjc.object_property(read_only=True, typestr=cxobjc.BOOL,
+                                           getter=is_dlss_enabled,
+                                           depends_on=["is_dlss_enabled_state"])
 
     @cxobjc.python_method
-    def is_esync_enabled(self):
-        return self.is_esync_enabled_state == BottleWrapper.STATUS_ESYNC_ENABLED
+    def is_dlss_available(self):
+        return self.is_dlss_enabled_state != BottleWrapper.STATUS_DLSS_UNAVAILABLE
 
-    isESyncEnabled = cxobjc.object_property(read_only=True, typestr=cxobjc.BOOL,
-                                            getter=is_esync_enabled,
-                                            depends_on=["is_esync_enabled_state"])
+    isDLSSAvailable = cxobjc.object_property(read_only=True, typestr=cxobjc.BOOL,
+                                             getter=is_dlss_available,
+                                             depends_on=["is_dlss_enabled_state"])
 
     #####
     #
@@ -600,9 +691,6 @@ class BottleWrapper(cxobjc.Proxy):
 
     @cxobjc.python_method
     def _enable_msync(self):
-        if self.is_esync_enabled():
-            self._disable_esync()
-
         self.set_config_value("EnvironmentVariables", "WINEMSYNC", "1")
         self.is_msync_enabled_state = BottleWrapper.STATUS_MSYNC_ENABLED
 
@@ -731,8 +819,8 @@ class BottleWrapper(cxobjc.Proxy):
         wine = os.path.join(cxutils.CX_ROOT, "bin", "wine")
         if applet.lower().endswith(".exe"):
             args = [wine, "--bottle", self.name, "--wl-app", applet]
-            if applet.lower() == "reboot.exe":
-                args.append("--show-gui")
+            if applet.lower() == "wineboot.exe":
+                args.append("--restart")
         elif applet.lower().endswith(".cpl"):
             args = [wine, "--bottle", self.name, "--wl-app", "rundll32", "shell32.dll,Control_RunDLL", applet]
         else:
@@ -757,9 +845,8 @@ class BottleWrapper(cxobjc.Proxy):
 
     @cxobjc.namedSelector(b'writeDescription')
     def write_description(self):
-        #  Note:  Expensive!  Should only be done within an operation.
         if self.get_config_value("Bottle", "Description", "") != self.current_description:
-            bottlemanagement.set_bottle_description(self.name, self.current_description)
+            self.set_config_value("Bottle", "Description", self.current_description)
 
     @cxobjc.python_method
     def wait_for_shutdown(self):
@@ -971,8 +1058,9 @@ class BottleWrapper(cxobjc.Proxy):
     @cxobjc.python_method
     def get_windows_version_display_name(self):
         version_name = bottlequery.get_windows_version_name(self.windows_version)
-        bitness = '32' if self.arch == 'win32' else '64'
-        return _('%(version)s %(bitness)s-bit') % {'version': version_name, 'bitness': bitness}
+        if self.arch == 'win32':
+            return _('%(version)s 32-bit (deprecated)') % {'version': version_name}
+        return version_name
 
     windows_version_display_name = property(get_windows_version_display_name)
 
@@ -1109,13 +1197,6 @@ class LoadControlPanelInfoOperation(BottleWrapperOperation):
     def main(self):
         self._control_panel_off_thread_table = bottlequery.get_control_panel_info(self.bottle.name)
 
-        if not distversion.IS_MACOSX:
-            self._control_panel_off_thread_table.append(["cxassoceditui", _("Edit Associations"),
-                                                         _("Manage the Windows programs used to open files in the native environment"), "cxassocedit"])
-
-            self._control_panel_off_thread_table.append(["cxmenueditui", _("Edit Menus"),
-                                                         _("Manage the menus and desktop icons in this bottle"), "cxmenuedit"])
-
     def finish(self):
         cptable = []
         for panel in self._control_panel_off_thread_table:
