@@ -9,25 +9,6 @@ import xml.sax.handler
 import cxlog
 import c4profiles
 
-def install_sax_workaround():
-    # work-around for a bug in xml.sax.xmlreader
-    # see http://mail.python.org/pipermail/python-bugs-list/2006-December/036370.html
-    def _self_contains(self, item):
-        try:
-            # pylint: disable=W0104
-            self[item] # Yes, pylint, this really does have an effect.
-            return True
-        except KeyError:
-            return False
-
-    # pylint: disable=W0621
-    import xml.sax.xmlreader
-
-    if not hasattr(xml.sax.xmlreader.AttributesImpl, '__contains__'):
-        xml.sax.xmlreader.AttributesImpl.__contains__ = _self_contains
-
-install_sax_workaround()
-
 class _C4PHandler(xml.sax.handler.ContentHandler):
 
 
@@ -845,13 +826,13 @@ class _C4PHandler(xml.sax.handler.ContentHandler):
         obj = self._objects[-1]
         value = ''.join(self._string)
         self.trace("obj=%s property=bottle_types value=%s" % (cxlog.debug_str(obj), cxlog.debug_str(value)))
-        if 'bottle_types' not in obj.__dict__:
-            obj.__dict__['bottle_types'] = {'use': [], 'install': []}
+        if '_bottle_types' not in obj.__dict__:
+            obj.__dict__['_bottle_types'] = {'use': [], 'install': []}
         if self._property == 'use':
-            obj.__dict__['bottle_types']['use'].append(value)
-            obj.__dict__['bottle_types']['install'].append(value)
+            obj.__dict__['_bottle_types']['use'].append(value)
+            obj.__dict__['_bottle_types']['install'].append(value)
         elif self._property == 'install':
-            obj.__dict__['bottle_types']['install'].append(value)
+            obj.__dict__['_bottle_types']['install'].append(value)
         self._states.pop()
         self.trace("objects=%d states=%d bottle_types" % (len(self._objects), len(self._states)))
 
