@@ -812,11 +812,11 @@ class C4ApplicationProfile:
 
     # The list of bottle types the application can be installed in.
     # The first entry is the default one.
-    bottle_types = {'use': ("win7", "win7_64", "win10", "win10_64",
-                            "winxp", "winxp_64", "win8", "win8_64",
-                            "winvista", "winvista_64",
-                            "win98", "win2000"),
-                    'install': ()}
+    _bottle_types = {'use': ("win10_64", "win10", "win7", "win7_64", "win11_64",
+                             "winxp", "winxp_64", "win8", "win8_64",
+                             "winvista", "winvista_64",
+                             "win98", "win2000"),
+                     'install': ()}
 
     # Used to group related applications in the same bottle.
     application_group = ""
@@ -896,7 +896,7 @@ class C4ApplicationProfile:
                      ('_description', 'category', 'medals', 'flags',
                       'installer_id', 'installed_key_pattern',
                       'installed_display_pattern', 'installed_registry_globs',
-                      'installed_file_globs', 'bottle_types',
+                      'installed_file_globs', '_bottle_types',
                       'application_group', 'download_urls', 'download_urls_64bit',
                       'download_page_urls', '_download_globs', 'extra_fors'
                      ))
@@ -929,8 +929,8 @@ class C4ApplicationProfile:
 
     download_page_url = property(_get_download_page_url)
 
-
-    def _get_platform(self):
+    @staticmethod
+    def _get_platform():
         """Ratings for Chrome OS are stored as "Android" for historical reasons."""
         return 'Android' if cxproduct.is_crostini() else distversion.PLATFORM
 
@@ -1054,6 +1054,19 @@ class C4ApplicationProfile:
 
     is_virtual = property(_getis_virtual)
 
+    def _getbottle_types(self):
+        bottle_types = {}
+        for purpose, types in self._bottle_types.items():
+            bottle_types[purpose] = []
+            for bottle_type in types:
+                if not bottle_type.endswith("_64") and \
+                   not cxproduct.get_config_boolean("OfficeSetup", "Enable32BitBottles", False):
+                    continue
+                bottle_types[purpose].append(bottle_type)
+
+        return bottle_types
+
+    bottle_types = property(_getbottle_types)
 
     def _getpreferred_bottle_type(self):
         """Returns the profile's preferred bottle type."""
