@@ -200,16 +200,14 @@ class CrossOver(Gtk.Application):
 
         self.main_window = self.crossover_gui.get_object("MainWindow")
 
-        global_config = cxproduct.get_config()
-
         if distversion.IS_CJBUILD:
-            first_run_version = global_config["CrossOver"].get("FirstRunVersion")
-            if (not first_run_version) or (first_run_version != distversion.CX_VERSION):
+            first_run_version = cxproduct.get_config_string("CrossOver", "FirstRunVersion", "")
+            if not first_run_version or first_run_version != distversion.CX_VERSION:
                 first_run_url = "https://www.crossoverchina.com/redirect/?product=Crossover&version=%s&referer=Start" % distversion.CX_VERSION
                 cxutils.launch_url(first_run_url)
-                cxproduct.set_config_value('CrossOver', 'FirstRunVersion', distversion.CX_VERSION)
+                cxproduct.set_config_string('CrossOver', 'FirstRunVersion', distversion.CX_VERSION)
 
-        size = global_config["OfficeSetup"].get("BottleManagerSize")
+        size = cxproduct.get_config_string("OfficeSetup", "BottleManagerSize", "")
         if size:
             width = height = None
             if size.count('x') == 1:
@@ -221,7 +219,7 @@ class CrossOver(Gtk.Application):
             if width is None:
                 cxlog.warn("Invalid BottleManagerSize %s" % cxlog.debug_str(size))
 
-        size = global_config["OfficeSetup"].get("BottleSidebarSize")
+        size = cxproduct.get_config_string("OfficeSetup", "BottleSidebarSize", "")
         if size and size.isdigit():
             self.crossover_gui.get_object("BottlePaned").set_position(int(size))
 
@@ -265,7 +263,7 @@ class CrossOver(Gtk.Application):
         self.bottle_context_menu.attach_to_widget(self.main_window)
         self.update_bottle_context_menu()
 
-        if global_config['OfficeSetup'].get('MenuBar', '0') == '1':
+        if cxproduct.get_config_boolean('OfficeSetup', 'MenuBar', False):
             self.main_window.set_titlebar(None)
             self.menubar_model = Gio.Menu()
             self.set_menubar(self.menubar_model)
@@ -327,7 +325,9 @@ class CrossOver(Gtk.Application):
                 return
 
         controller = ratingdialog.RatingController(bottle, self.main_window, 'reminder' in options)
-        self.add_window(controller.get_window())
+        window = controller.get_window()
+        if window:
+            self.add_window(window)
 
     def do_command_line(self, command_line):
         options = command_line.get_options_dict()
@@ -456,12 +456,12 @@ class CrossOver(Gtk.Application):
                                                  BottleListItem.compare)
 
     def update_profiles(self):
-        config = cxproduct.get_config()
-        if config['OfficeSetup'].get('AutoUpdate', '1') != '0':
+        if cxproduct.get_config_boolean('OfficeSetup', 'AutoUpdate', True):
             op = UpdateCompatDBOperation()
             pyop.sharedOperationQueue.enqueue(op)
 
-            c4p_url = config['OfficeSetup'].get('TieURL', 'http://ftp.codeweavers.com/pub/crossover/tie/crossover.tie.gz')
+            c4p_url = cxproduct.get_config_string(
+                'OfficeSetup', 'TieURL', 'http://ftp.codeweavers.com/pub/crossover/tie/crossover.tie.gz')
             if c4p_url:
                 op = UpdateProfilesOperation(c4p_url, self)
                 pyop.sharedOperationQueue.enqueue(op)
@@ -601,12 +601,8 @@ class CrossOver(Gtk.Application):
                         'app.graphics-wine': _("_Wine graphics backend"),
                     },
                     {
-                        'app.toggle-esync': _('Performance Enhanced Synchronization (_ESync)'),
                         'app.toggle-highres': _('_High Resolution Mode'),
                         'app.toggle-preview': _('CrossOver Preview'),
-                    },
-                    {
-                        'app.reset-browser': _('_Reset Default Web Browser to Linux Browser'),
                     }
                 ]
             },
@@ -622,10 +618,9 @@ class CrossOver(Gtk.Application):
             }
         ]
 
-        global_config = cxproduct.get_config()
         if not distversion.HAS_MULTI_USER or (
                 not cxproduct.is_root_install() and
-                global_config["OfficeSetup"].get("NonRootPublish", "0") != "1"):
+                not cxproduct.get_config_boolean("OfficeSetup", "NonRootPublish", False)):
             self.remove_menu_item(menu_list, 'app.publish-bottle')
             self.remove_menu_item(menu_list, 'app.update-published-bottle')
 
@@ -767,10 +762,11 @@ class CrossOver(Gtk.Application):
         self.update_actions()
 
     def bottleChanged(self, bottle):
-        # This can be called from outside the main thread
-        GLib.idle_add(self.update_bottle_list)
+        assert pyop.is_main_thread()
+
+        self.update_bottle_list()
         if bottle == self.selected_bottle:
-            GLib.idle_add(self.update_actions)
+            self.update_actions()
 
     def reveal_bottle(self, bottle):
         for i in range(self.bottle_list_store.get_n_items()):
@@ -798,9 +794,9 @@ class CrossOver(Gtk.Application):
 
         self.bottles.removeChangeDelegate(self)
         if self._size:
-            cxproduct.set_config_value('OfficeSetup', 'BottleManagerSize', '%sx%s' % self._size)
+            cxproduct.set_config_string('OfficeSetup', 'BottleManagerSize', '%sx%s' % self._size)
         if self._pane_size:
-            cxproduct.set_config_value('OfficeSetup', 'BottleSidebarSize', str(self._pane_size))
+            cxproduct.set_config_string('OfficeSetup', 'BottleSidebarSize', str(self._pane_size))
 
     def on_BottleListView_button_press_event(self, view, event):
         row = view.get_row_at_y(int(event.y))
@@ -908,7 +904,6 @@ class CrossOver(Gtk.Application):
             'publish-bottle': self.on_publish_bottle_activate,
             'update-published-bottle': self.on_update_published_bottle_activate,
             'create-package': self.on_create_package_activate,
-            'reset-browser': self.on_reset_browser_activate,
             'install-into-bottle': self.on_install_activate,
             'install-missing': self.on_install_missing_activate,
             'quit-bottle': self.on_quit_bottle_activate,
@@ -925,7 +920,6 @@ class CrossOver(Gtk.Application):
             'graphics-auto': self.on_graphics_auto_change_state,
             'graphics-dxvk': self.on_graphics_dxvk_change_state,
             'graphics-wine': self.on_graphics_wine_change_state,
-            'toggle-esync': self.on_esync_change_state,
             'toggle-highres': self.on_highres_change_state,
             'toggle-preview': self.on_preview_change_state,
             'toggle-auto-update': self.on_auto_update_change_state,
@@ -934,6 +928,7 @@ class CrossOver(Gtk.Application):
             'toggle-show-untested': self.on_show_untested_change_state,
             'toggle-cxfixes': self.on_cxfixes_change_state,
             'toggle-menubar': self.on_menubar_change_state,
+            'toggle-32bit-bottles': self.on_32bit_bottles_change_state,
         }
 
         for name, callback in toggle_entries.items():
@@ -949,19 +944,20 @@ class CrossOver(Gtk.Application):
         action.connect('activate', self.on_open_file_activate)
         self.add_action(action)
 
-        global_config = cxproduct.get_config()
         self.lookup_action('toggle-auto-update').set_state(GLib.Variant.new_boolean(
-            global_config['OfficeSetup'].get('AutoUpdate', '1') == '1'))
+            cxproduct.get_config_boolean('OfficeSetup', 'AutoUpdate', True)))
         self.lookup_action('toggle-update-check').set_state(GLib.Variant.new_boolean(
-            global_config['CrossOver'].get('CheckForUpdates', '1') == '1'))
+            cxproduct.get_config_boolean('CrossOver', 'CheckForUpdates', True)))
         self.lookup_action('toggle-ratings').set_state(GLib.Variant.new_boolean(
-            global_config['CrossOver'].get('AskForRatings', '1') == '1'))
+            cxproduct.get_config_boolean('CrossOver', 'AskForRatings', True)))
         self.lookup_action('toggle-show-untested').set_state(GLib.Variant.new_boolean(
-            global_config['OfficeSetup'].get('ShowUntestedApps', '1') == '1'))
+            cxproduct.get_config_boolean('OfficeSetup', 'ShowUntestedApps', True)))
         self.lookup_action('toggle-cxfixes').set_state(GLib.Variant.new_boolean(
-            global_config['OfficeSetup'].get('ApplyCxfixes', '1') == '1'))
+            cxproduct.get_config_boolean('OfficeSetup', 'ApplyCxfixes', True)))
         self.lookup_action('toggle-menubar').set_state(GLib.Variant.new_boolean(
-            global_config['OfficeSetup'].get('MenuBar', '0') == '1'))
+            cxproduct.get_config_boolean('OfficeSetup', 'MenuBar', False)))
+        self.lookup_action('toggle-32bit-bottles').set_state(GLib.Variant.new_boolean(
+            cxproduct.get_config_boolean('OfficeSetup', 'Enable32BitBottles', False)))
 
     # Update actions
 
@@ -986,21 +982,6 @@ class CrossOver(Gtk.Application):
             self.lookup_action('graphics-dxvk').set_state(GLib.Variant.new_boolean(False))
             self.lookup_action('graphics-wine').set_state(GLib.Variant.new_boolean(False))
 
-    def update_esync_toggle(self):
-        state = bottlewrapper.BottleWrapper.STATUS_ESYNC_UNKNOWN
-        if self.selected_bottle:
-            state = self.selected_bottle.is_esync_enabled_state
-
-        if state == bottlewrapper.BottleWrapper.STATUS_ESYNC_UNKNOWN:
-            self.lookup_action('toggle-esync').set_enabled(False)
-            self.lookup_action('toggle-esync').set_state(GLib.Variant.new_boolean(False))
-        elif state == bottlewrapper.BottleWrapper.STATUS_ESYNC_ENABLED:
-            self.lookup_action('toggle-esync').set_enabled(True)
-            self.lookup_action('toggle-esync').set_state(GLib.Variant.new_boolean(True))
-        elif state == bottlewrapper.BottleWrapper.STATUS_ESYNC_DISABLED:
-            self.lookup_action('toggle-esync').set_enabled(True)
-            self.lookup_action('toggle-esync').set_state(GLib.Variant.new_boolean(False))
-
     def update_highres_toggle(self):
         state = bottlewrapper.BottleWrapper.STATUS_HIGHRES_UNKNOWN
         if self.selected_bottle:
@@ -1055,15 +1036,12 @@ class CrossOver(Gtk.Application):
         self.lookup_action('default-bottle').set_state(GLib.Variant.new_boolean(cond))
 
         cond = self.selected_bottle is not None and not self.selected_bottle.is_busy
-        for item in ('duplicate-bottle', 'delete-bottle',
-                     'open-c-drive', 'export-bottle',
+        for item in ('duplicate-bottle', 'delete-bottle', 'export-bottle',
                      'create-package', 'default-bottle'):
             self.lookup_action(item).set_enabled(cond)
 
-        cond = self.selected_bottle is not None and \
-            not self.selected_bottle.is_managed and \
-            self.selected_bottle.can_run_commands
-        self.lookup_action('reset-browser').set_enabled(cond)
+        cond = self.selected_bottle is not None and self.selected_bottle.is_usable
+        self.lookup_action('open-c-drive').set_enabled(cond)
 
         cond = self.selected_bottle is not None and self.selected_bottle.is_active
         self.lookup_action('quit-bottle').set_enabled(cond)
@@ -1073,7 +1051,6 @@ class CrossOver(Gtk.Application):
         self.lookup_action('force-quit-bottle').set_enabled(cond)
 
         self.update_graphics_toggle()
-        self.update_esync_toggle()
         self.update_highres_toggle()
         self.update_preview_toggle()
 
@@ -1107,7 +1084,8 @@ class CrossOver(Gtk.Application):
             not self.selected_bottle.is_managed and \
             not self.selected_bottle.is_disabled
 
-        for item in ('graphics-auto', 'graphics-dxvk', 'toggle-esync', 'toggle-highres'):
+        for item in ('graphics-auto', 'graphics-dxvk', 'graphics-wine',
+                     'toggle-highres'):
             self.lookup_action(item).set_enabled(cond)
 
         cond = self.selected_bottle is not None and \
@@ -1273,12 +1251,6 @@ class CrossOver(Gtk.Application):
 
         packagebottledialog.PackageBottleController(self.selected_bottle, self.main_window)
 
-    def on_reset_browser_activate(self, _action, _parameter):
-        if not self.selected_bottle:
-            return
-
-        bottlequery.set_native_browser(self.selected_bottle.name)
-
     def on_install_activate(self, _action, parameter):
         if self.selected_bottle and (not self.selected_bottle.is_usable or self.selected_bottle.is_managed):
             return
@@ -1387,15 +1359,6 @@ class CrossOver(Gtk.Application):
 
         self.lookup_action('graphics').change_state(GLib.Variant.new_string('wine'))
 
-    def on_esync_change_state(self, action, value):
-        if self.updating_checkboxes or not self.selected_bottle:
-            return
-
-        action.set_state(value)
-        state = value.get_boolean()
-
-        bottleoperation.set_esync_state(self.selected_bottle, state, self.main_window)
-
     def on_highres_change_state(self, action, value):
         if self.updating_checkboxes or not self.selected_bottle:
             return
@@ -1416,43 +1379,50 @@ class CrossOver(Gtk.Application):
 
     def on_auto_update_change_state(self, action, value):
         action.set_state(value)
-        cxproduct.set_config_value('OfficeSetup', 'AutoUpdate', '1' if value.get_boolean() else '0')
+        cxproduct.set_config_boolean('OfficeSetup', 'AutoUpdate', value.get_boolean())
 
         self.update_profiles()
 
     @staticmethod
     def on_update_check_change_state(action, value):
         action.set_state(value)
-        cxproduct.set_config_value('CrossOver', 'CheckForUpdates', '1' if value.get_boolean() else '0')
+        cxproduct.set_config_boolean('CrossOver', 'CheckForUpdates', value.get_boolean())
 
     @staticmethod
     def on_ratings_change_state(action, value):
         action.set_state(value)
-        cxproduct.set_config_value('CrossOver', 'AskForRatings', '1' if value.get_boolean() else '0')
+        cxproduct.set_config_boolean('CrossOver', 'AskForRatings', value.get_boolean())
 
     def on_show_untested_change_state(self, action, value):
         action.set_state(value)
-        cxproduct.set_config_value('OfficeSetup', 'ShowUntestedApps', '1' if value.get_boolean() else '0')
+        cxproduct.set_config_boolean('OfficeSetup', 'ShowUntestedApps', value.get_boolean())
 
         self.package_view_controller.update_profiles()
 
     @staticmethod
     def on_cxfixes_change_state(action, value):
         action.set_state(value)
-        cxproduct.set_config_value('OfficeSetup', 'ApplyCxfixes', '1' if value.get_boolean() else '0')
+        cxproduct.set_config_boolean('OfficeSetup', 'ApplyCxfixes', value.get_boolean())
 
     @staticmethod
     def on_menubar_change_state(action, value):
         action.set_state(value)
-        cxproduct.set_config_value('OfficeSetup', 'MenuBar', '1' if value.get_boolean() else '0')
+        cxproduct.set_config_boolean('OfficeSetup', 'MenuBar', value.get_boolean())
+
+    @staticmethod
+    def on_32bit_bottles_change_state(action, value):
+        action.set_state(value)
+        cxproduct.set_config_boolean('OfficeSetup', 'Enable32BitBottles', value.get_boolean())
 
 
 def run_cxfixes(check_64bit=True):
-    global_config = cxproduct.get_config()
-    if global_config['OfficeSetup'].get('ApplyCxfixes', '1') == '1':
-        flags = cxdiag.CHECK_32BIT
-        if check_64bit:
-            flags |= cxdiag.CHECK_64BIT
+    if cxproduct.get_config_boolean('OfficeSetup', 'ApplyCxfixes', True):
+        if cxproduct.is_wow64_install():
+            flags = cxdiag.CHECK_64BIT
+        else:
+            flags = cxdiag.CHECK_32BIT
+            if check_64bit:
+                flags |= cxdiag.CHECK_64BIT
         diag = cxdiag.get(None, flags)
         cxfixes.clear_errors()
         for errid, title in diag.warnings.items():
@@ -1504,8 +1474,7 @@ class NewBottleController:
             liststore = Gtk.ListStore(str, str) # display name, template
             templatewidget.set_model(liststore)
             index = 0
-            for template in sorted(bottlemanagement.template_list(),
-                                   key=bottlemanagement.get_template_key):
+            for template in bottlemanagement.template_list():
                 display_name = bottlemanagement.get_template_name(template)
                 new_row = liststore.append()
                 liststore.set_value(new_row, 0, display_name)
