@@ -18,6 +18,7 @@ import globtree
 import bottlequery
 import cxaiebase
 import cxaiemedia
+import distversion
 import appdetector
 
 
@@ -608,6 +609,9 @@ class AIECore(cxaiebase.AIETask):
         if 'no_installer' in self.state:
             return True
 
+        if distversion.IS_MACOSX:
+            return True
+
         if not self.download or 'uncompressed' in self.state:
             install_source = self.state['install_source']
         else:
@@ -877,7 +881,7 @@ class AIECore(cxaiebase.AIETask):
         engine = self.scheduler
         cmd = [os.path.join(cxutils.CX_ROOT, "bin", "wine"),
                "--bottle", engine.installtask.bottlename,
-               "--wait-children", "--wl-app", "reboot.exe"]
+               "--wait-children", "--wl-app", "wineboot.exe", "--restart"]
         # FIXME: Make interruptible.
         retcode, _out, err = cxutils.run(cmd, env=engine.state['environ'],
                                          stderr=cxutils.GRAB)
@@ -908,6 +912,9 @@ class AIECore(cxaiebase.AIETask):
 
 
     def _main_setup_bottle_selinux(self):
+        if distversion.IS_MACOSX:
+            return True
+
         engine = self.scheduler
         cdrive = bottlequery.get_native_path(engine.installtask.bottlename, "c:")
         cmd = [os.path.join(cxutils.CX_ROOT, "bin", "wine"),
@@ -1071,15 +1078,40 @@ class AIECore(cxaiebase.AIETask):
 
         return True
 
-    def _main_cxhack_install_dxvk(self):
-        if self.installer.parent.appid != 'com.codeweavers.c4.17117':
+    def _main_cxhack_msync(self):
+        if self.installer.parent.appid != 'com.codeweavers.c4.21821' or \
+           not distversion.IS_MACOSX:
             return True
 
+        engine = self.scheduler
         bottlename = self.scheduler.installtask.bottlename
-        cxbottle = bottlequery.get_config(bottlename).get_save_config()
 
+        cmd = [os.path.join(cxutils.CX_ROOT, "bin", "wine"),
+               "--bottle", bottlename,
+               "--wl-app", "wineboot", "--", "--end-session",
+               "--shutdown", "--force", "--kill"]
+
+        retcode, _out, err = cxutils.run(cmd, env=engine.state['environ'],
+                                         stderr=cxutils.GRAB)
+        if retcode:
+            self.error = err
+            return False
+
+        bottlequery.shutdown_manipulator(bottlename)
+
+        cmd = [os.path.join(cxutils.CX_ROOT, "bin", "wine"),
+               "--bottle", bottlename, "--no-update",
+               "--ux-app", "wineserver", "-w"]
+
+        retcode, _out, err = cxutils.run(cmd, env=engine.state['environ'],
+                                         stderr=cxutils.GRAB)
+        if retcode:
+            self.error = err
+            return False
+
+        cxbottle = bottlequery.get_config(bottlename).get_save_config()
         cxbottle.lock_file()
-        cxbottle['EnvironmentVariables']['WINEDXVK'] = '1'
+        cxbottle['EnvironmentVariables']['WINEMSYNC'] = '1'
         cxbottle.save_and_unlock_file()
 
         return True
@@ -1157,9 +1189,9 @@ class AIECore(cxaiebase.AIETask):
                     'collate_menus_and_assocs',
                     'cxhack_mplayer2',
                     'cxhack_cxhtml',
+                    'cxhack_msync',
                     'remove_fake_dlls',
                     'cxhack_pre_office2013',
-                    'cxhack_install_dxvk',
                     'run_installer_and_check',
                     'copy_files',
                     'reboot',
