@@ -407,6 +407,10 @@ class AIEDownload(cxaiebase.AIETask):
 
     checksum = property(_getchecksum)
 
+    @property
+    def download_page_url(self):
+        return self.aiecore.installer.parent.app_profile.download_page_url or self.url
+
 
     def validate_installer(self, filename):
         """Checks whether the specified file is valid.
