@@ -219,7 +219,7 @@ class Engine(cxaiebase.AIEScheduler):
             if channels is not None:
                 env['CX_DEBUGMSG'] = channels
             elif 'CX_DEBUGMSG' not in env:
-                env['CX_DEBUGMSG'] = "+cxreboot,-cxassoc,-cxmenu"
+                env['CX_DEBUGMSG'] = "+wineboot,-cxassoc,-cxmenu"
 
     @cxobjc.python_method
     def log_system_info(self):
