@@ -633,7 +633,7 @@ class File(Raw):
         Raw.__init__(self)
         self._read_only = True
         self._filename = filename
-        self._mtime = None
+        self._digest = None
         self._file_lock = None
         self.refresh()
         cxfsnotifier.add_observer(self._filename, self._fs_observer)
@@ -688,13 +688,9 @@ class File(Raw):
         start = time.time()
         self.lock()
         try:
-            try:
-                mtime = os.path.getmtime(self._filename)
-            except OSError:
-                mtime = None
-            if self._mtime == mtime:
+            if self._digest and not self._digest.modified():
                 return
-            self._mtime = mtime
+            self._digest = cxutils.FileDigest(self._filename)
 
             try:
                 self._read_only = False
@@ -768,11 +764,7 @@ class File(Raw):
                     cxlog.log("saving '%s'\n" % cxlog.to_str(self._filename))
                     self.write(self._filename)
                 self.modified = False
-                # Update _mtime so we don't immediately and needlessly reload it
-                try:
-                    self._mtime = os.path.getmtime(self._filename)
-                except OSError:
-                    self._mtime = None
+                self._digest = cxutils.FileDigest(self._filename)
                 self.emit_event(MODIFIED)
             else:
                 cxlog.log("'%s' not modified -> no need to save\n" % cxlog.to_str(self._filename))
