@@ -14,7 +14,7 @@ import distversion
 from cxutils import cxgettext as _
 
 FIXES_URL = "http://ftp.codeweavers.com/pub/crossover/cxfixes/cxfixes.xml.gz"
-WIKI_URL = "https://www.codeweavers.com/support/wiki/Diag/"
+WIKI_URL = "https://support.codeweavers.com/missing-libraries/"
 
 
 #####
@@ -51,7 +51,7 @@ def run_from_main_thread(fun):
 
     if gtk_level == 0:
         if not checkgtk.init_check():
-            raise Exception('No display found')
+            raise RuntimeError('No display found')
 
         Gtk.main()
 
@@ -299,19 +299,6 @@ def _load_fixes():
 #
 #####
 
-_BITNESS = None
-
-def detect_bitness():
-    # pylint: disable=W0603
-    global _BITNESS
-    if _BITNESS is None:
-        # We don't detect bitness through uname to correctly deal with chroots.
-        _BITNESS = '64' # default to 64-bit
-        with open('/bin/ls', 'rb') as f:
-            if f.read(5) == b'\x7fELF\x01':
-                _BITNESS = '32'
-    return _BITNESS
-
 _DISTROID = None
 
 def detect_distribution():
@@ -461,7 +448,7 @@ def get_error_title(errid):
 def get_error_url(errid):
     # Redirect the BrokenLib issues to the MissingLib ones:
     # one page per library is more than enough pages.
-    if errid.endswith('.amd64'):
+    if errid.endswith('.amd64') or errid.endswith('.arm64'):
         errid = errid[:-6]
     errid = errid.replace('brokenlib', 'missinglib', 1).replace('.', '-')
     return WIKI_URL + errid
@@ -508,7 +495,7 @@ def strip_fix_overrides(sources, errid, key):
         return (key[0], bitnesses[0])
     return (key[0], None)
 
-def get_fix(errid, distroid=None, bitness=None):
+def get_fix(errid, distroid=None):
     _load_fixes()
     if errid not in CXFIXES.fixes:
         return (None, None, None)
@@ -535,13 +522,11 @@ def get_fix(errid, distroid=None, bitness=None):
 
     if distroid is None:
         distroid = detect_distribution()
-    if bitness is None:
-        bitness = detect_bitness()
 
     while distroid:
         dist = CXFIXES.distributions.get(distroid, None)
-        if (distroid, bitness) in merged_fixes:
-            return (merged_fixes, distroid, bitness)
+        if (distroid, '64') in merged_fixes:
+            return (merged_fixes, distroid, '64')
         if (distroid, None) in merged_fixes:
             return (merged_fixes, distroid, None)
         distroid = dist.fallback
@@ -561,11 +546,20 @@ def get_distribution_property(distroid, name):
         dist = CXFIXES.distributions[dist.fallback]
     return dist.__dict__[name]
 
-def get_packages(errid, distroid=None, bitness=None, pre=None):
+def get_commands(errid, distroid=None):
     _load_fixes()
 
     # Return the packages for all the relevant errors
-    (distfixes, fix_distroid, fix_bitness) = get_fix(errid, distroid, bitness)
+    (distfixes, fix_distroid, fix_bitness) = get_fix(errid, distroid)
+    if fix_distroid is None:
+        return []
+    return distfixes[(fix_distroid, fix_bitness)].commands
+
+def get_packages(errid, distroid=None, pre=None):
+    _load_fixes()
+
+    # Return the packages for all the relevant errors
+    (distfixes, fix_distroid, fix_bitness) = get_fix(errid, distroid)
     if fix_distroid is None:
         return []
     packages = []
@@ -580,10 +574,14 @@ def get_package_key(name):
         return name[:-5]
     if name.endswith(':amd64'): # Debian
         return name[:-6]
+    if name.endswith(':arm64'): # Debian
+        return name[:-6]
     if name.endswith('.i686'): # Fedora
         return name[:-5]
     if name.endswith('.x86_64'): # Fedora
         return name[:-7]
+    if name.endswith('.aarch64'): # Fedora
+        return name[:-8]
     if name.endswith('-32bit'): # openSUSE
         return name[:-6]
     if name.startswith('lib32-'): # Arch
@@ -597,7 +595,6 @@ def get_fix_command(update=True, checklock=False, allatonce=True, yes=False):
     distroid = detect_distribution()
     if distroid is None:
         return ([], None)
-    bitness = detect_bitness()
 
     # First make sure the method for fixing errors in distribution is one
     # we know about. Currently that's the packagecmd method.
@@ -616,12 +613,13 @@ def get_fix_command(update=True, checklock=False, allatonce=True, yes=False):
 
     fixable_errids = []
     package_sets = {}
+    command_list = []
     has_arch32 = False
     has_deb32 = False
     prepackages = set()
     for errid in _ERRORS:
-        prepackages.update(get_packages(errid, distroid, bitness, pre=True))
-        fix_packages = get_packages(errid, distroid, bitness, pre=False)
+        prepackages.update(get_packages(errid, distroid, pre=True))
+        fix_packages = get_packages(errid, distroid, pre=False)
         if fix_packages:
             fixable_errids.append(errid)
             package_set = set(fix_packages)
@@ -648,11 +646,21 @@ def get_fix_command(update=True, checklock=False, allatonce=True, yes=False):
                 key = get_package_key(package)
                 package_sets[key] = package_set
 
-    if not package_sets:
+        commands = get_commands(errid, distroid)
+        if commands:
+            fixable_errids.append(errid)
+            command_list.extend(commands)
+
+    if not fixable_errids:
         return ([], None)
 
+    if not package_sets:
+        return (fixable_errids, '; '.join(command_list))
+
+    if command_list:
+        cmd += '; '.join(command_list) + '; '
     if prepackages:
-        cmd = pkg_cmd + ' ' + cxutils.argvtocmdline(prepackages) + '; ' + cmd
+        cmd += pkg_cmd + ' ' + cxutils.argvtocmdline(prepackages) + '; '
     if allatonce:
         all_packages = set()
         for package_set in package_sets.values():
@@ -684,11 +692,11 @@ def get_fix_command(update=True, checklock=False, allatonce=True, yes=False):
         # Ignore update errors, hoping the package list was not too outdated
         cmd = updatecmd + "; " + cmd
 
-    if bitness == '64' and has_arch32:
+    if has_arch32:
         # If we need to install an Arch multilib package do make sure the
         # multilib repository is enabled.
         cmd = arch_add_multilib(cmd)
-    elif bitness == '64' and has_deb32:
+    elif has_deb32:
         # If we need to install a Debian multiarch package, make sure we have
         # the required architecture. Note that 32-bit distributions don't
         # support 64-bit packages. Note that this does not need the dpkg lock.
@@ -787,14 +795,24 @@ def markup_error_message(message):
     return '\n'.join(lines)
 
 def get_fix_message(distfixes, distroid, bitness, distname=True):
-    cmd = get_distribution_property(detect_distribution(), 'packagecmd')
-    args = [cmd]
+    msg = ''
     prepackages = distfixes[(distroid, bitness)].prepackages
-    if prepackages:
-        args.extend(sorted(prepackages))
-        args.extend((';', cmd))
-    args.extend(sorted(distfixes[(distroid, bitness)].packages))
-    msg = ' '.join(args)
+    packages = distfixes[(distroid, bitness)].packages
+    if prepackages or packages:
+        args = []
+        cmd = get_distribution_property(detect_distribution(), 'packagecmd')
+        args.append(cmd)
+        if prepackages:
+            args.extend(sorted(prepackages))
+            args.extend((';', cmd))
+        args.extend(sorted(packages))
+        msg = ' '.join(args)
+
+    commands = distfixes[(distroid, bitness)].commands
+    if commands:
+        args = [msg] if msg else []
+        args.extend(commands)
+        msg = '; '.join(args)
 
     if distname:
         name = CXFIXES.distributions[distroid].name
@@ -815,7 +833,6 @@ def get_error_message(prefix=True, verbose=False):
 
     # Get an error message for each errid
     distroid = detect_distribution()
-    bitness = detect_bitness()
     errid2msg = {}
     msg2errid = {} # deduplicate issues that have identical fixes
     status2errid = {'fix': set(), 'nofix': set(), 'other': set(), 'missing': set()}
@@ -824,7 +841,8 @@ def get_error_message(prefix=True, verbose=False):
         errmsg = ''
         if distfixes is None:
             status = 'missing'
-        elif fix_distroid and distfixes[(fix_distroid, fix_bitness)].packages:
+        elif fix_distroid and (distfixes[(fix_distroid, fix_bitness)].packages or
+                               distfixes[(fix_distroid, fix_bitness)].commands):
             status = 'fix'
             errmsg = '  ' + get_fix_message(distfixes, fix_distroid, fix_bitness, distname=False) + '\n'
         elif fix_distroid:
@@ -836,7 +854,7 @@ def get_error_message(prefix=True, verbose=False):
             lines = []
             for (other_distroid, other_bitness) in distfixes:
                 if (other_distroid != distroid or \
-                    (other_bitness is not None and other_bitness != bitness)) and \
+                    (other_bitness is not None and other_bitness != '64')) and \
                     distfixes[(other_distroid, other_bitness)].packages:
                     lines.append(get_fix_message(distfixes, other_distroid, other_bitness))
             if lines:
@@ -878,7 +896,7 @@ def get_error_message(prefix=True, verbose=False):
             msg = errid2msg[seed_errid]
             for errid in sorted(msg2errid[(group, msg)]):
                 lib = _ERRORS[errid].lib
-                if errid.endswith('.amd64'):
+                if errid.endswith('.amd64') or errid.endswith('.arm64'):
                     bits = '64-bit, '
                 elif lib is not None or errid + '.amd64' in CXFIXES.fixes:
                     bits = '32-bit, '
