@@ -267,6 +267,9 @@ class CXDistFix:
     # This field is optional.
     packages = frozenset()
 
+    # A set of commands to execute instead of installing a package.
+    commands = frozenset()
+
     def __init__(self, distid, bitness):
         self.distid = distid
         self.bitness = bitness
@@ -298,7 +301,7 @@ class CXDistFix:
             raise AttributeError("CXDistFix.distid is not set in issue %s" % errid)
         if self.bitness not in CXDistFix.BITNESSES:
             raise AttributeError("Invalid bitness value %s for %s" % (self.bitness, self.display_name(errid)))
-        if self.bitness and self.bitness != '64' and errid.endswith(".amd64"):
+        if self.bitness and self.bitness != '64' and (errid.endswith(".amd64") or errid.endswith(".arm64")):
             raise AttributeError("The %s error cannot happen on the 32-bit %s distribution" % (errid, self.distid))
         for package in self.packages:
             if not CXDistFix._PACKAGE_RE.search(package):
@@ -306,7 +309,7 @@ class CXDistFix:
         return True
 
     def dump(self, out, indent=""):
-        _dump_fields(out, indent, self, ('distid', 'bitness', 'packages'))
+        _dump_fields(out, indent, self, ('distid', 'bitness', 'packages', 'commands'))
 
 
 class CXFix:
@@ -372,6 +375,14 @@ class CXFix:
 
     ### Instance validation and dumping
 
+    @staticmethod
+    def _suffix(errid):
+        if errid.endswith(".amd64"):
+            return "amd64"
+        if errid.endswith(".arm64"):
+            return "arm64"
+        return ""
+
     def validate(self):
         """Checks that all the mandatory fields have been set for this fix.
 
@@ -382,12 +393,12 @@ class CXFix:
             raise AttributeError("CXFix.errid is not set")
         if not self.distfixes and not self.fallback:
             raise AttributeError("No actual fixes are present for CXFix %s" % self.errid)
-        is64bit = self.errid.endswith(".amd64")
-        if self.fallback and self.fallback.endswith(".amd64") != is64bit:
-            raise AttributeError("32-/64-bit mismatch in fallback: %s vs. %s" % (self.errid, self.fallback))
+        suffix = self._suffix(self.errid)
+        if self.fallback and self._suffix(self.fallback) != suffix:
+            raise AttributeError("Architecture mismatch in fallback: %s vs. %s" % (self.errid, self.fallback))
         for maskedby in self.maskedby:
-            if maskedby.endswith(".amd64") != is64bit:
-                raise AttributeError("32-/64-bit mismatch in <tiedto> or <maskedby>: %s vs. %s" % (self.errid, maskedby))
+            if self._suffix(maskedby) != suffix:
+                raise AttributeError("Architecture mismatch in <tiedto> or <maskedby>: %s vs. %s" % (self.errid, maskedby))
         for distfix in self.distfixes.values():
             distfix.validate(self.errid)
         return True
@@ -484,20 +495,21 @@ class CXFixes:
     def _prepare_fix(self, prepared, fix):
         prepared.add(fix.errid)
 
-        bitness = 64 if fix.errid.endswith(".amd64") else 32
+        errid = fix.errid.replace(".amd64", "").replace(".arm64", "")
+        bitness = 32 if fix.errid == errid else 64
         missing = 0
         if fix.title is None:
             lib = fix.lib
-            if fix.errid.startswith("missinglib"):
+            if errid.startswith("missinglib"):
                 if lib is None:
-                    lib = fix.errid[7:] if bitness == 32 else fix.errid[7:-6]
+                    lib = errid[7:]
                 fix.title = _("Missing %(bitness)s-bit %(library)s library") % {'bitness': bitness, 'library': lib}
-            elif fix.errid.startswith("brokenlib"):
+            elif errid.startswith("brokenlib"):
                 if lib is None:
-                    lib = fix.errid[6:] if bitness == 32 else fix.errid[6:-6]
+                    lib = errid[6:]
                 fix.title = _("Broken %(bitness)s-bit %(library)s library") % {'bitness': bitness, 'library': lib}
-            elif fix.errid.startswith("missinggstreamer1"):
-                gst = fix.errid[17:] if bitness == 32 else fix.errid[17:-6]
+            elif errid.startswith("missinggstreamer1"):
+                gst = errid[17:]
                 fix.title = _("Missing %(bitness)s-bit gst-plugins-%(plugin)s GStreamer plugins") % {'bitness': bitness, 'plugin': gst}
             else:
                 missing += 1
@@ -505,7 +517,7 @@ class CXFixes:
             missing += 1
 
         if missing and bitness == 64:
-            missing -= self._fill_in(prepared, fix, fix.errid[:-6])
+            missing -= self._fill_in(prepared, fix, errid)
 
         if missing and fix.fallback:
             self._fill_in(prepared, fix, fix.fallback)
@@ -516,7 +528,7 @@ class CXFixes:
             if brokenid not in self.fixes:
                 lib = fix.lib
                 if lib is None:
-                    lib = fix.errid[7:] if bitness == 32 else fix.errid[7:-6]
+                    lib = errid[7:]
                 brokentitle = _("Broken %(bitness)s-bit %(library)s library") % {'bitness': bitness, 'library': lib}
                 self.fixes[brokenid] = CXFix(brokenid, None, fix.lib, brokentitle, fix.description)
 
