@@ -8,25 +8,6 @@ import xml.sax.handler
 import cxlog
 import cxfixesobjs
 
-def install_sax_workaround():
-    # work-around for a bug in xml.sax.xmlreader
-    # see http://mail.python.org/pipermail/python-bugs-list/2006-December/036370.html
-    def _self_contains(self, item):
-        try:
-            # pylint: disable=W0104
-            self[item] # Yes, pylint, this really does have an effect.
-            return True
-        except KeyError:
-            return False
-
-    # pylint: disable=W0621
-    import xml.sax.xmlreader
-
-    if not hasattr(xml.sax.xmlreader.AttributesImpl, '__contains__'):
-        xml.sax.xmlreader.AttributesImpl.__contains__ = _self_contains
-
-install_sax_workaround()
-
 class _CXFixesHandler(xml.sax.handler.ContentHandler):
 
     def __init__(self):
@@ -234,31 +215,31 @@ class _CXFixesHandler(xml.sax.handler.ContentHandler):
 
     #####
     #
-    # String set properties
+    # String list properties
     #
     # This parses a tag of the form '<tag>string</tag>' and puts the string
-    # in the <current-object>.<prop> set.
+    # in the <current-object>.<prop> list.
     #
     #####
 
-    def _startof_stringset(self, prop):
+    def _startof_stringlist(self, prop):
         self._property = prop
         self._string = []
-        self._states.append(_CXFixesHandler.state_stringset)
+        self._states.append(_CXFixesHandler.state_stringlist)
         cxlog.log_('cxfixesparser', "objects=%d states=%d %s" % (len(self._objects), len(self._states), cxlog.to_str(prop)))
 
-    def _endof_stringset(self, _unused):
+    def _endof_stringlist(self, _unused):
         obj = self._objects[-1]
         value = ''.join(self._string)
         cxlog.log_('cxfixesparser', "obj=%s property=%s value=%s" % (cxlog.debug_str(obj), cxlog.to_str(self._property), cxlog.debug_str(value)))
         if self._property not in obj.__dict__:
-            obj.__dict__[self._property] = set((value,))
+            obj.__dict__[self._property] = [value]
         else:
-            obj.__dict__[self._property].add(value)
+            obj.__dict__[self._property].append(value)
         self._states.pop()
         cxlog.log_('cxfixesparser', "objects=%d states=%d %s" % (len(self._objects), len(self._states), cxlog.to_str(self._property)))
 
-    state_stringset = (_startof_unexpected, _endof_stringset, _string_characters)
+    state_stringlist = (_startof_unexpected, _endof_stringlist, _string_characters)
 
 
     #####
@@ -510,7 +491,7 @@ class _CXFixesHandler(xml.sax.handler.ContentHandler):
 
     def _childof_glob(self, name, _attrs):
         if name == 'pattern':
-            self._startof_stringset('patterns')
+            self._startof_stringlist('patterns')
         else:
             self._startof_skip(name)
 
@@ -608,6 +589,8 @@ class _CXFixesHandler(xml.sax.handler.ContentHandler):
             setname = 'prepackages' if attrs.get('preinstall', False) else 'packages'
             self._attr2stringset(setname, 'name', attrs)
             self._startof_childless(name)
+        elif name == 'command':
+            self._startof_stringlist('commands')
         else:
             self._startof_skip(name)
 
