@@ -82,6 +82,50 @@ def check_fake_dll(path):
                 return True
     return False
 
+class FileDigest:
+    def __init__(self, filename):
+        self._filename = filename
+        self._mtime, self._size, self._inode = self.stat()
+        self._hash = self.hash()
+        self._time = time.time()
+
+    def stat(self):
+        try:
+            res = os.stat(self._filename)
+            return res.st_mtime, res.st_size, res.st_ino
+        except OSError:
+            return None, None, None
+
+    def hash(self):
+        try:
+            try:
+                with open(self._filename, 'rb') as f:
+                    return hashlib.file_digest(f, 'sha1').hexdigest()
+            except AttributeError:
+                pass
+
+            sha1 = hashlib.sha1()
+            with open(self._filename, 'rb') as f:
+                while True:
+                    chunk = f.read(8192)
+                    if not chunk:
+                        break
+                    sha1.update(chunk)
+            return sha1.hexdigest()
+        except OSError:
+            return None
+
+    def existed(self):
+        return self._mtime is not None
+
+    def modified(self):
+        mtime, size, inode = self.stat()
+        if mtime != self._mtime or size != self._size or inode != self._inode:
+            return True
+        if mtime and mtime > self._time - 0.1:
+            return self.hash() != self._hash
+        return False
+
 #####
 #
 # Cross-process lock
@@ -608,6 +652,67 @@ def version_as_tuple():
 #
 #####
 
+def get_user_languages():
+    try:
+        from Foundation import NSLocale
+        languages = []
+        for language in NSLocale.preferredLanguages():
+            if language == 'pt':
+                # On Mac OS X 'pt' is identical to 'pt-BR' instead of
+                # 'pt-PT' as is the case on other Unix platforms.
+                languages.append('pt-BR')
+            elif language == 'zh-Hans':
+                # zh-Hans is what RFC 5646 specifies for Simplified Chinese but
+                # everywhere else we derive the language id from the zh_CN Unix
+                # locale. So convert here.
+                languages.append('zh-CN')
+            elif language == 'zh-Hant':
+                # Same as for zh-Hans but for Traditional Chinese.
+                languages.append('zh-TW')
+            else:
+                languages.append(language)
+        return languages
+    except ImportError:
+        # Probe $LANGUAGE manually because getlocale() would only return
+        # the first locale it contains. Normally $LANGUAGE only specifies the
+        # language, not a full locale. But that should not be an issue for the
+        # remainder of this function.
+        locales = os.environ.get('LANGUAGE', '')
+        if locales == '':
+            locales, _encoding = locale.getlocale()
+            if locales is None:
+                locales = ''
+
+        languages = []
+        for loc in locales.split(':'):
+            # The user may have set LANG='french' which we would be unable to deal
+            # with. So ensure it gets normalized to something like 'fr_FR'. But we
+            # must also make sure something like 'fr' does not get converted to
+            # 'fr_FR'.
+            normalized = locale.normalize(loc)
+            if not normalized.startswith(loc + '_'):
+                loc = normalized
+            # Remove the encoding and modifier that we are not interested in
+            loc = loc.split('.')[0].split('@')[0]
+
+            if loc in ('C', ''):
+                # These two are synonymous with English
+                languages.append('en')
+            elif loc == 'pt_PT':
+                # This is synonymous with pt which is what we normally use
+                languages.append('pt')
+            elif '-' in loc:
+                # In theory getlocale() may return a locale where the part
+                # before the underscore already follows RFC 1766. So if that's the
+                # case pass it through unmolested.
+                languages.append(loc.split('_')[0])
+            else:
+                # This is the most common case. We transform a locale of the
+                # form 'fr_FR' into what we hope will be a valid language
+                # identifier like 'fr-FR'.
+                languages.append(loc.replace('_', '-'))
+        return languages
+
 _SINGLETON_RE = re.compile("(-x)?-[a-z]$")
 _PREFERRED_LANGUAGES = {}
 _LANGUAGE_ASSOCIATIONS = {
@@ -631,7 +736,7 @@ def get_preferred_languages(language=None):
     if language:
         languages = [language]
     else:
-        languages = distversion.get_user_languages()
+        languages = get_user_languages()
         if not languages:
             languages = ['en']
 
@@ -755,6 +860,81 @@ def cxgettext(message):
 _ = cxgettext
 
 
+#####
+#
+# Logging functions
+#
+#####
+
+
+@cxobjc.method(CXUtils, 'installerLoggingPreset')
+def installer_logging_preset():
+    return {
+        "channels": ["+relay", "+msi", "+setupapi"],
+        "label": _("Install (very verbose)"),
+    }
+
+
+@cxobjc.method(CXUtils, 'loggingPresets')
+def logging_presets():
+    graphics_environment = ["VKD3D_DEBUG=trace", "VKD3D_SHADER_DEBUG=trace"]
+    if distversion.IS_MACOSX:
+        graphics_environment.append("MVK_CONFIG_LOG_LEVEL=4")
+
+    window_channels = ["+event", "+win", "+x11drv"]
+    if distversion.IS_MACOSX:
+        window_channels = ["+event", "+win", "+macdrv"]
+
+    return [
+        {
+            "channels": ["+relay"],
+            "label": _("Relay (very verbose)"),
+        },
+        {
+            "channels": ["+file", "+ntdll"],
+            "label": _("File Access"),
+        },
+        {
+            "channels": ["+font"],
+            "label": _("Fonts"),
+        },
+        {
+            "channels": ["+dinput", "+joystick", "+winmm", "+xinput"],
+            "label": _("Game Controllers"),
+        },
+        {
+            "channels": ["+d3d"],
+            "environment": graphics_environment,
+            "label": _("Game Graphics"),
+        },
+        {
+            "channels": ["+event", "+key", "+keyboard"],
+            "label": _("Keyboard Input"),
+        },
+        {
+            "channels": ["+cursor", "+event"],
+            "label": _("Mouse Input"),
+        },
+        {
+            "channels": ["+iphlpapi", "+winhttp", "+wininet", "+winsock"],
+            "label": _("Network Connections"),
+        },
+        {
+            "channels": ["+print", "+psdrv", "+winspool", "+localspl"],
+            "label": _("Printing"),
+        },
+        {
+            "channels": ["+mmdevapi", "+winmm", "+driver", "+msacm", "+midi", "+dsound", "+dsound3d",
+                         "+xaudio2", "+xapofx", "+dmusic", "+mci", "+pulse", "+oss", "+alsa", "+coreaudio"],
+            "label": _("Sound (verbose)"),
+        },
+        {
+            "channels": window_channels,
+            "label": _("Window Behavior"),
+        },
+    ]
+
+
 #####
 #
 # Dealing with subprocesses
@@ -779,8 +959,8 @@ def run(args, stdout=None, stderr=None,
     logprefix is set, then the trace is prefixed with it.
 
     """
+    start = time.time()
     if cxlog.is_on():
-        start = time.time()
         if logprefix != "":
             logprefix = logprefix + ": "
         bg = ""
