@@ -63,7 +63,6 @@ def demo_status(licenseFile, sigFile):
     return (False, username, expiration, licenseID, False)
 
 
-@cxobjc.method(DemoUtils, 'canRegisterWithLicenseDir_')
 def can_register_as_current_user(licenseDir):
     """ Returns True if we have current permission to register. Return
         False if we need to authenticate as root before registering.
@@ -133,7 +132,7 @@ def checkSerialCodeRegistrationResponse(responseBuffer):
     elif responseBuffer.find("BADEMAIL", 0, 16) != -1:
         errorString = _("The email address you have entered is not in a valid format. Please enter a valid email address.\n\n") + lastResort()
     elif responseBuffer.find("SERIALREGISTERED", 0, 16) != -1:
-        errorString = _("The activation code you have entered has already been registered, and cannot be used again.") + " " + lastResortErroneous()
+        errorString = _("The activation code you have entered has already been registered, and cannot be used again. Please click 'Take Me to Normal Unlocking' to unlock CrossOver with your user name and password.") + " " + lastResortErroneous()
     elif responseBuffer.find("EXPIRED", 0, 16) != -1:
         errorString = _("The activation code you have entered has expired and can no longer be used.") + " " + lastResortErroneous()
     elif responseBuffer.find("ERROR", 0, 16) != -1:
