@@ -51,8 +51,7 @@ class InstallerViewController:
         self.profile = None
         self.delegates = []
 
-        global_config = cxproduct.get_config()
-        self.show_untested_apps = (global_config['OfficeSetup'].get('ShowUntestedApps', '1') != '0')
+        self.show_untested_apps = cxproduct.get_config_boolean('OfficeSetup', 'ShowUntestedApps', True)
 
         self.images = {}
         self.installation_details = []
@@ -97,7 +96,7 @@ class InstallerViewController:
         icon = cxguitools.get_std_icon('cxexe', ('64x64', ))
         self.xml.get_object('PackageIcon').set_from_pixbuf(icon)
 
-        self.xml.get_object('BackButton').set_visible(global_config['OfficeSetup'].get('MenuBar', '0') == '1')
+        self.xml.get_object('BackButton').set_visible(cxproduct.get_config_boolean('OfficeSetup', 'MenuBar', False))
 
         self.set_drag_destination()
 
@@ -124,9 +123,12 @@ class InstallerViewController:
 
     def set_icon(self, path):
         if path and os.path.exists(path):
-            size = 64
-            icon = GdkPixbuf.Pixbuf.new_from_file_at_size(path, size, size)
-            self.xml.get_object('PackageIcon').set_from_pixbuf(icon)
+            try:
+                size = 64
+                icon = GdkPixbuf.Pixbuf.new_from_file_at_size(path, size, size)
+                self.xml.get_object('PackageIcon').set_from_pixbuf(icon)
+            except GLib.GError:
+                cxlog.warn(f"Icon at {path} cannot be loaded")
 
     def auto_fill_settings(self):
         self.install_task.auto_fill_settings()
@@ -330,7 +332,8 @@ class InstallerViewController:
         # remaining cxdiag errors and warnings
         for errid, info in self.install_task.get_cxdiag_messages().items():
             packages = cxfixes.get_packages(errid)
-            if not packages or not self.install_task.apply_cxfixes:
+            commands = cxfixes.get_commands(errid)
+            if (not packages and not commands) or not self.install_task.apply_cxfixes:
                 description = cxfixes.get_error_description(errid)
                 if info.level == 'required':
                     result['errors'].append('<a style="color:red;" href="%(url)s">%(title)s</a>: %(description)s' % {
@@ -627,16 +630,18 @@ class InstallerViewController:
         self.update_installation_notes()
         self.update_installation_details()
 
-        bottle = collection.bottle_with_name(self.install_task.bottlename)
+        bottle = existing_bottle or collection.bottle_with_name(self.install_task.bottlename)
         if bottle:
             bottle.remove_all_status_overrides(bottle.STATUS_INSTALLING)
 
         if self.status == INSTALLATION_COMPLETED:
             self.xml.get_object('InstallButton').hide()
-            bottle.callback('reveal_bottle', bottle)
+            if bottle:
+                bottle.callback('reveal_bottle', bottle)
         else:
             self.install_task.trigger_bottle_analysis()
-            bottle.callback('select_install')
+            if bottle:
+                bottle.callback('select_install')
 
     def set_custom_installer_source(self, path):
         self.install_task.set_installer_source(path)
@@ -872,14 +877,16 @@ class InstallerViewController:
 
     # BottleWrapper delegate functions
     def bottleChanged(self, bottle):
+        assert pyop.is_main_thread()
+
         if self.status != INSTALLATION_NOT_STARTED:
             return
 
         if bottle.can_install != (bottle.name in self.install_task.bottles):
-            GLib.idle_add(self.bottleCollectionChanged)
+            self.bottleCollectionChanged()
 
         if bottle.installed_packages_ready:
-            GLib.idle_add(self.install_task.installed_applications_ready, bottle)
+            self.install_task.installed_applications_ready(bottle)
 
 
 class InstallTask:
@@ -1019,10 +1026,10 @@ class InstallTask:
             secondary = cxutils.html_escape(self.aietask.error)
 
         url = None
+        if hasattr(self.aietask, 'download_page_url'):
+            url = self.aietask.download_page_url
         if self.parent.profile.app_profile:
-            url = self.parent.profile.app_profile.download_page_url
-        if hasattr(self.aietask, 'url'):
-            url = url or self.aietask.url
+            url = url or self.parent.profile.app_profile.download_page_url
 
         if hasattr(self.aietask, 'needs_download') and self.aietask.needs_download and url:
             secondary += _("\n\nIf you have a working internet connection via your browser, you can download this file here:\n\n<a href=\"%(url)s\">%(url)s</a>") % {'url': cxutils.html_escape(url)}
