@@ -7,6 +7,7 @@ import re
 import cxfixes
 import cxlog
 import cxobjc
+import cxproduct
 import cxutils
 import distversion
 
@@ -541,9 +542,12 @@ class TargetBottle:
         if appid == self._profile.appid and self._sourcetype == 'file' and \
            self._sourcefile is not None:
             properties['sourcefile'] = os.path.basename(self._sourcefile)
-        flags = cxdiag.CHECK_32BIT
-        if self.is64bit():
-            flags |= cxdiag.CHECK_64BIT
+        if cxproduct.is_wow64_install():
+            flags = cxdiag.CHECK_64BIT
+        else:
+            flags = cxdiag.CHECK_32BIT
+            if self.is64bit():
+                flags |= cxdiag.CHECK_64BIT
         diag = cxdiag.get(self.bottlename, flags)
         for prop, value in diag.properties.items():
             if prop not in properties:
@@ -949,8 +953,9 @@ class InstallTask(cxobjc.Proxy):
                 result.add(condition.value)
         return result
 
+    @staticmethod
     @cxobjc.python_method
-    def _scan_url_locales(self, urls, default_locales, nondefault_locales):
+    def _scan_url_locales(urls, default_locales, nondefault_locales):
         # urls may be a dictionary of strings to string, or strings to tuple, that doesn't matter for our usage.
         if '' in urls:
             default_url = urls['']
@@ -1248,8 +1253,9 @@ class InstallTask(cxobjc.Proxy):
             self._clear_installer_source(flush_delegate=True)
 
     # On macOS, don't search user directories since it triggers annoying permission dialogs
+    @staticmethod
     @cxobjc.python_method
-    def download_search_paths(self):
+    def download_search_paths():
         if distversion.IS_MACOSX:
             return ()
         return (os.environ.get('HOME', '/'), cxutils.get_download_dir(), cxutils.get_desktop_dir())
@@ -1662,7 +1668,7 @@ class InstallTask(cxobjc.Proxy):
     #####
 
     @cxobjc.namedSelector(b'isNewBottleNameValid:')
-    def is_new_bottle_name_valid(self, new_bottle_name):
+    def is_new_bottle_name_valid(self, new_bottle_name): # pylint: disable=R0201
         """Returns True if the new bottle name is valid and False otherwise.
 
         In particular this checks for that it does not match an existing
@@ -1856,6 +1862,7 @@ class InstallTask(cxobjc.Proxy):
             check = check.lower()
             if check.startswith('apprequire:') or check.startswith('apprecommend:'):
                 issue_id = check.split(':', 1)[1]
+                new_level = 'suggested'
                 if check.startswith('apprequire:'):
                     new_level = 'required'
                 elif check.startswith('apprecommend:'):
@@ -1876,8 +1883,9 @@ class InstallTask(cxobjc.Proxy):
 
         return filtered
 
+    @staticmethod
     @cxobjc.python_method
-    def _cxdiag_level_cmp(self, a, b):
+    def _cxdiag_level_cmp(a, b):
         levels = ['suggested', 'recommended', 'required']
         try:
             return cxutils.cmp(levels.index(a), levels.index(b))
@@ -1901,9 +1909,12 @@ class InstallTask(cxobjc.Proxy):
         """Returns a dictionary of cxdiag messages that apply to the current
         profile."""
 
-        flags = cxdiag.CHECK_32BIT
-        if self.is64bit():
-            flags |= cxdiag.CHECK_64BIT
+        if cxproduct.is_wow64_install():
+            flags = cxdiag.CHECK_64BIT
+        else:
+            flags = cxdiag.CHECK_32BIT
+            if self.is64bit():
+                flags |= cxdiag.CHECK_64BIT
         diag = cxdiag.get(self._get_existing_bottle_name(), flags)
 
         # Add the masked issues to the list
@@ -2055,7 +2066,13 @@ class InstallTask(cxobjc.Proxy):
                     cxutils.sanitize_bottlename(self.new_bottle_name)):
                 result['errors'].append(_("There is already a bottle named '%s'") % cxutils.html_escape(self.bottlename))
             else:
-                if self.target_bottle.bottlename:
+                # FIXME: 32-bit bottle hack
+                if self.application_name and self.profile and \
+                   'Microsoft Office' in self.application_name and \
+                   not self.profile.app_profile.preferred_bottle_type and \
+                   not cxproduct.get_config_boolean("OfficeSetup", "Enable32BitBottles", False):
+                    result['errors'].append("'%s' needs to be installed in a 32-bit bottle. Please enable them through the preferences dialog." % self.application_name)
+                elif self.target_bottle.bottlename:
                     if self.application_name:
                         if self.target_bottle.compatible:
                             result['notes'].append(_("CrossOver will install '%(application)s' into the '%(bottlename)s' bottle") % {
@@ -2139,7 +2156,8 @@ class InstallTask(cxobjc.Proxy):
 
 @cxobjc.method(InstallTask, 'getMissingDependencies_')
 def get_missing_dependencies(bottle):
-    if bottle and bottle.profile and bottle.profile.app_profile:
+    if bottle and bottle.can_run_commands and bottle.installed_packages_ready and \
+       bottle.profile and bottle.profile.app_profile:
         profile = bottle.profile.copy()
         profile.app_profile.steamid = None
 
