@@ -57,7 +57,7 @@ class UpdateController:
         if not parent:
             self.xml.get_object("UpdaterDialog").connect('destroy', self.quit_requested)
 
-        package_info = cxproduct.get_config_value('CrossOver', 'ProductPackage', None)
+        package_info = cxproduct.get_config_string('CrossOver', 'ProductPackage', '')
         if package_info:
             self.package_type, _sep, _package_name = package_info.partition(':')
 
@@ -132,7 +132,7 @@ class UpdateController:
         self.destroy()
 
     def on_never_clicked(self, _button):
-        cxproduct.set_config_value('CrossOver', 'CheckForUpdates', '0')
+        cxproduct.set_config_boolean('CrossOver', 'CheckForUpdates', False)
         self.destroy()
 
     def on_install_clicked(self, _button):
