@@ -163,7 +163,7 @@ sub run_inf($$$;$)
         }
 
         if ($winearch eq "win64" and
-            -f "$ENV{CX_ROOT}/bin/wineloader" and
+            -d "$ENV{CX_ROOT}/lib/wine/i386-windows" and
             cxsystem("$ENV{CX_ROOT}/bin/wine", "--wl32-app", "rundll32.exe",
                      "--no-quotes", "--scope", $scope, @cxoptions,
                      "--desktop", "root", "--dll", $ENV{WINEDLLOVERRIDES},
@@ -459,6 +459,7 @@ sub upgrade_graphics_settings()
     $env_var_config->set("CX_GRAPHICS_BACKEND", "d3dmetal") if (
         !defined $env_var_config->get("CX_GRAPHICS_BACKEND") and $enable_d3dmetal eq "1");
 
+
     $bottle_config->save();
 }
 
